@@ -56,9 +56,33 @@ struct
 	drop_privs = { 0, 0 };
 #endif
 
+static void
+make_pidfile(void)
+	{
+#if !defined(WIN32)
+	FILE	*f;
+
+	if (!_GK.pidfile)
+		return;
+	f = fopen(_GK.pidfile, "w");
+	fprintf(f, "%d\n", getpid());
+	fclose(f);
+#endif
+	}
+
+static void
+remove_pidfile(void)
+	{
+#if !defined(WIN32)
+	if (_GK.pidfile)
+		unlink(_GK.pidfile);
+#endif
+	}
+
 static void
 cb_sigterm(gint sig)
 	{
+	remove_pidfile();
     exit(0);
 	}
 
@@ -303,6 +327,8 @@ parse_config(gchar *config, gchar *arg)
 	else if (!strcmp(config, "inet-interval"))
 		_GK.inet_interval = atoi(arg);
 #if !defined(WIN32)
+	else if (!strcmp(config, "pidfile"))
+		_GK.pidfile = g_strdup(arg);
 	else if (!strcmp(config, "user") || !strcmp(config, "U"))
 		{
 		struct passwd *tmp;
@@ -389,15 +415,18 @@ usage(void)
 	{
 	printf(_("usage: gkrellmd [options]\n"));
 	printf(_("options:\n"));
-	printf(_("   -u, --update-hz F      Monitor update frequency.\n"));
-	printf(_("   -m, --max-clients N    Number of simultaneous clients.\n"));
-	printf(_("   -P, --port P           Server port to listen on.\n"));
-	printf(_("   -a, --allow-host host  Allow connections from specified hosts.\n"));
-	printf(_("   -c, --clear-hosts      Clears the current list of allowed hosts.\n"));
+	printf(_("   -u, --update-hz F         Monitor update frequency\n"));
+	printf(_("   -m, --max-clients N       Number of simultaneous clients\n"));
+	printf(_("   -P, --port P              Server port to listen on\n"));
+	printf(_("   -a, --allow-host host     Allow connections from specified hosts\n"));
+	printf(_("   -c, --clear-hosts         Clears the current list of allowed hosts\n"));
+	printf(_("       --io-timeout N        Close connection after N seconds of no I/O\n"));
+	printf(_("       --reconnect-timeout N Try to connect every N seconds after\n"
+	         "                             a disconnect\n"));
 #if !defined(WIN32)
-	printf(_("   -d, --detach           Run in background and detach from terminal.\n"));
-	printf(_("   -U, --user username    Change to this username after startup.\n"));
-	printf(_("   -G, --group groupname  Change to this group after startup.\n"));
+	printf(_("   -d, --detach              Run in background and detach from terminal\n"));
+	printf(_("   -U, --user username       Change to this username after startup\n"));
+	printf(_("   -G, --group groupname     Change to this group after startup\n"));
 #endif
 	printf(_("   -V, --verbose\n"));
 	printf(_("   -v, --version\n"));
@@ -572,6 +601,7 @@ detach_from_terminal(void)
 	if (daemon(0, 0))
 		{
 		fprintf(stderr, "gkrellmd detach failed: %s\n", strerror(errno));
+		remove_pidfile();
 		exit(1);
 		}
 #else
@@ -582,6 +612,7 @@ detach_from_terminal(void)
 	if (i < 0 || setsid() == -1)		/* new session process group */
 		{
 		fprintf(stderr, "gkrellmd detach failed: %s\n", strerror(errno));
+		remove_pidfile();
 		exit(1);
 		}
 
@@ -680,6 +711,8 @@ main(gint argc, gchar **argv)
 		signal(SIGTSTP, SIG_IGN);
 		}
 
+	make_pidfile();
+
 	gkrellm_sys_main_init();
 	drop_privileges();
 	g_thread_init(NULL);
@@ -700,6 +733,7 @@ main(gint argc, gchar **argv)
 	if (_GK.server_fd == NULL)
 		{
 		fprintf(stderr, "gkrellmd socket() failed: %s\n", strerror(errno));
+		remove_pidfile();
 		exit(1);
 		}
 
@@ -711,6 +745,7 @@ main(gint argc, gchar **argv)
 		if (listen(_GK.server_fd[i], 5) == -1)
 			{
 			fprintf(stderr, "gkrellmd listen() failed: %s\n", strerror(errno));
+			remove_pidfile();
 			exit(1);
 			}
 		FD_SET(_GK.server_fd[i], &read_fds);
@@ -747,6 +782,7 @@ main(gint argc, gchar **argv)
 			if (errno == EINTR)
 				continue;
 			fprintf(stderr, "gkrellmd select() failed: %s\n", strerror(errno));
+			remove_pidfile();
 			exit(1);
 			}
 #if 0	/* BUG, result is 0 when test_fds has a set fd!! */
@@ -776,6 +812,7 @@ main(gint argc, gchar **argv)
 					{
 					fprintf(stderr, "gkrellmd accept() failed: %s\n",
 							strerror(errno));
+					remove_pidfile();
 					exit(1);
 					}
 				if (client_fd > max_fd)
