@@ -1230,6 +1230,7 @@ gkrellm_fs_add_to_mounts_list(gchar *dir, gchar *dev, gchar *type)
 		m->type = g_strdup(type);
 		mounts_list = g_list_append(mounts_list, m);
 		mounts_list_modified = TRUE;
+		serveflag_done_list = g_list_append(serveflag_done_list, &m->changed);
 
 		for (i = 0; i < (sizeof(remote_fs_types) / sizeof(gchar *)); ++i)
 			{
@@ -1304,6 +1305,8 @@ refresh_mounts_list(void)
 			g_free(m->directory);
 			g_free(m->device);
 			g_free(m->type);
+			serveflag_done_list = g_list_remove(serveflag_done_list,
+						&m->changed);
 			if (m->busy)
 				m->deleted = TRUE;
 			else
@@ -1405,7 +1408,6 @@ serve_fs_data(GkrellmdClient *client)
 			d = g_strconcat(s, buf, NULL);
 			g_free(s);
 			s = d;
-			m->changed = FALSE;
 			}
 		}
 	else
@@ -1422,7 +1424,6 @@ serve_fs_data(GkrellmdClient *client)
 			d = g_strconcat(s, buf, NULL);
 			g_free(s);
 			s = d;
-			m->changed = FALSE;
 			}
 		if (*s)
 			{
@@ -1496,38 +1497,68 @@ gkrellm_mail_get_active_thread(void)
 	}
 
 /* ======================================================= */
-struct
+typedef struct
 	{
-	gboolean	changed;
-	gboolean	battery_is_available,
-				ac_is_on_line,
-				battery_is_charging;
-	gint		battery_percentage;
-	gint		battery_time_left;
+	gboolean	changed,
+				have_data;
+
+	gint		id;
+	gboolean	present,
+				on_line,
+				charging;
+	gint		percent;
+	gint		time_left;
+	}
+	Battery;
+
+GList	*battery_list;
+
+
+static Battery *
+battery_nth(gint n)
+	{
+	Battery		*bat;
+	static gint	n_batteries;
+
+	if (n < 0 || n > 10)
+		return NULL;
+	while ((bat = (Battery *)g_list_nth_data(battery_list, n)) == NULL)
+		{
+		bat = g_new0(Battery, 1);
+		battery_list = g_list_append(battery_list, bat);
+		bat->id = n_batteries++;
+		serveflag_done_list = g_list_append(serveflag_done_list,
+								&bat->changed);
+		}
+	return bat;
 	}
-	bat;
 
 void
-gkrellm_battery_assign_data(gint id, gboolean available, gboolean on_line,
+gkrellm_battery_assign_data(gint id, gboolean present, gboolean on_line,
 			gboolean charging, gint percent, gint time_left)
 	{
-	if (id > 0)
-		return;		/* Fix to handle more than one battery later */
+	Battery	*bat;
 
-	if (   available != bat.battery_is_available
-		|| on_line   != bat.ac_is_on_line
-		|| charging  != bat.battery_is_charging
-		|| percent   != bat.battery_percentage
-		|| time_left != bat.battery_time_left
+	bat = battery_nth(id);
+	if (!bat)
+		return;
+
+	if (   present   != bat->present
+		|| on_line   != bat->on_line
+		|| charging  != bat->charging
+		|| percent   != bat->percent
+		|| time_left != bat->time_left
 	   )
 		{
-		bat.battery_is_available = available;
-		bat.ac_is_on_line = on_line;
-		bat.battery_is_charging = charging;
-		bat.battery_percentage = percent;
-		bat.battery_time_left = time_left;
-		bat.changed = TRUE;
+		bat->present = present;
+		bat->on_line = on_line;
+		bat->charging = charging;
+		bat->percent = percent;
+		bat->time_left = time_left;
+		bat->changed = TRUE;
 		}
+
+	bat->have_data = TRUE;
 	}
 
 gint
@@ -1539,21 +1570,49 @@ gkrellm_battery_full_cap_fallback()
 static void
 update_battery(gboolean force)
 	{
+	GList	*list;
+
 	if (force || GK.five_second_tick)
+		{
+		for (list = battery_list; list; list = list->next)
+			((Battery *) list->data)->have_data = FALSE;
 		gkrellm_sys_battery_read_data();
+		}
 	}
 
 static gchar *
 serve_battery_data(GkrellmdClient *client)
 	{
-	gchar		*s;
+	Battery		*bat;
+	GList		*list;
+	gchar		buf[128], *d, *s;
 
-	if (!bat.changed && client->served)
-		return NULL;
-	s = g_strdup_printf("<battery>\n%d %d %d %d %d\n",
-				bat.battery_is_available,
-				bat.ac_is_on_line, bat.battery_is_charging,
-				bat.battery_percentage, bat.battery_time_left);
+	s = g_strdup("");
+	for (list = battery_list; list; list = list->next)
+		{
+		bat = (Battery *) list->data;
+		if (!bat->have_data && bat->present)
+			{
+			bat->present = FALSE;
+			bat->changed = TRUE;
+			}
+		if (   (!bat->changed && client->served)
+			|| (!check_client_version(client, 2,1,9) && bat->id > 0)
+		   )
+			continue;
+		sprintf(buf, "%d %d %d %d %d %d\n",
+					bat->present, bat->on_line, bat->charging,
+					bat->percent, bat->time_left, bat->id);
+		d = g_strconcat(s, buf, NULL);
+		g_free(s);
+		s = d;
+		}
+	if (*s)
+		{
+		d = g_strconcat("<battery>\n", s, NULL);
+		g_free(s);
+		s = d;
+		}
 	return s;
 	}
 
@@ -1561,7 +1620,7 @@ static void
 serve_battery_setup(GkrellmdClient *client)
 	{
 	gkrellm_sys_battery_read_data();
-	if (bat.battery_is_available)
+	if (battery_list)
 		{
 		send_to_client(client->fd, "<battery_setup>\nbattery_available\n");
 		}
@@ -1580,7 +1639,6 @@ init_battery_monitor(void)
 	{
 	if (!gkrellm_sys_battery_init())
 		return NULL;
-	serveflag_done_list = g_list_append(serveflag_done_list, &bat.changed);
 	return &battery_monitor;
 	}
 
