@@ -434,8 +434,14 @@ gkrellm_alert_create(GkrellmPanel *p, gchar *name, gchar *unit_string,
 	alert->step1 = step1;
 	alert->digits = digits;
 
+	alert->alarm_command = g_strdup("");
+	alert->warn_command = g_strdup("");
+	alert->voice_string = g_strdup("");
+	alert->do_alarm_command = alert->do_warn_command = TRUE;
+
 	gkrellm_alert_set_triggers(alert, min_low, min_low, min_low, min_low);
 	alert->activated = FALSE;
+	alert->check_hardwired = FALSE;
 
 	return alert;
 	}
@@ -458,6 +464,15 @@ gkrellm_alert_set_triggers(GkrellmAlert *alert,
 		alert->low.alarm_limit = low_alarm;
 		}
 	alert->activated = TRUE;
+	alert->check_hardwired = TRUE;
+	}
+
+void
+gkrellm_alert_commands_config(GkrellmAlert *alert,
+						gboolean alarm, gboolean warn)
+	{
+	alert->do_alarm_command = alarm;
+	alert->do_warn_command = warn;
 	}
 
 void
@@ -512,13 +527,15 @@ gkrellm_alert_dup(GkrellmAlert **a_dst, GkrellmAlert *a_src)
 	}
 
 static void
-reset_alert(GkrellmAlert *alert)
+reset_alert(GkrellmAlert *alert, gboolean suppress)
 	{
 	GkrellmTrigger	*th = &alert->high,
 					*tl = &alert->low;
 
-	if (   ((th->alarm_on || tl->alarm_on) && alert->alarm_repeat_set == 0)
-		|| ((th->warn_on || tl->warn_on) && alert->warn_repeat_set == 0)
+	if (   suppress
+		&& (   ((th->alarm_on || tl->alarm_on) && alert->alarm_repeat_set == 0)
+			|| ((th->warn_on || tl->warn_on) && alert->warn_repeat_set == 0)
+		   )
 	   )
 		alert->suppress_command = TRUE;
 	th->alarm_on = FALSE;
@@ -533,14 +550,23 @@ reset_alert(GkrellmAlert *alert)
 void
 gkrellm_reset_alert(GkrellmAlert *alert)
 	{
-	GList	*list;
-
 	if (!alert)
 		return;
-	list = g_list_find(gkrellm_alert_list, alert);
-	if (list)
+	if (g_list_find(gkrellm_alert_list, alert))
 		{
-		reset_alert(alert);
+		reset_alert(alert, FALSE);
+		gkrellm_alert_list = g_list_remove(gkrellm_alert_list, alert);
+		}
+	}
+
+void
+gkrellm_reset_alert_soft(GkrellmAlert *alert)
+	{
+	if (!alert)
+		return;
+	if (g_list_find(gkrellm_alert_list, alert))
+		{
+		reset_alert(alert, TRUE);
 		gkrellm_alert_list = g_list_remove(gkrellm_alert_list, alert);
 		}
 	}
@@ -563,7 +589,7 @@ gkrellm_reset_panel_alerts(GkrellmPanel *p)
 			if (alert->panel != p)
 				continue;
 			done = FALSE;
-			reset_alert(alert);
+			reset_alert(alert, FALSE);
 			gkrellm_alert_list = g_list_remove(gkrellm_alert_list, alert);
 			break;
 			}
@@ -580,7 +606,7 @@ reset_all_alerts(void)
 	GList	*list;
 
 	for (list = gkrellm_alert_list; list; list = list->next)
-		reset_alert((GkrellmAlert *) list->data);
+		reset_alert((GkrellmAlert *) list->data, TRUE);
 	g_list_free(gkrellm_alert_list);
 	gkrellm_alert_list = NULL;
 	}
@@ -731,45 +757,54 @@ alert_apply(GtkWidget *widget, GkrellmAlert **ap)
 	gint			n;
 
 	alert = *ap;
-	if (alert->check_high)
+
+	if (alert->high.alarm_limit_spin_button)
 		{
 		spin = GTK_SPIN_BUTTON(alert->high.alarm_limit_spin_button);
 		alert->high.alarm_limit = gtk_spin_button_get_value(spin);
 		spin = GTK_SPIN_BUTTON(alert->high.warn_limit_spin_button);
 		alert->high.warn_limit = gtk_spin_button_get_value(spin);
 		}
-	if (alert->check_low)
+
+	if (alert->low.alarm_limit_spin_button)
 		{
 		spin = GTK_SPIN_BUTTON(alert->low.alarm_limit_spin_button);
 		alert->low.alarm_limit = gtk_spin_button_get_value(spin);
 		spin = GTK_SPIN_BUTTON(alert->low.warn_limit_spin_button);
 		alert->low.warn_limit = gtk_spin_button_get_value(spin);
 		}
-	spin = GTK_SPIN_BUTTON(alert->alarm_repeat_spin_button);
-	alert->alarm_repeat_set = gtk_spin_button_get_value_as_int(spin);
-	spin = GTK_SPIN_BUTTON(alert->warn_repeat_spin_button);
-	alert->warn_repeat_set = gtk_spin_button_get_value_as_int(spin);
-	if (alert->voice_repeat_spin_button)
-		{
-		spin = GTK_SPIN_BUTTON(alert->voice_repeat_spin_button);
-		alert->voice_repeat_set = gtk_spin_button_get_value_as_int(spin);
-		}
-	s = gkrellm_gtk_entry_get_text(&alert->alarm_command_entry);
-	gkrellm_dup_string(&alert->alarm_command, s);
-	if (!*s)
-		alert->alarm_repeat_set = 0;
-	if (alert->high.alarm_on || alert->low.alarm_on)
-		alert->alarm_repeat = alert->alarm_repeat_set;
 
-	s = gkrellm_gtk_entry_get_text(&alert->warn_command_entry);
-	gkrellm_dup_string(&alert->warn_command, s);
-	if (!*s)
-		alert->warn_repeat_set = 0;
-	if (alert->high.warn_on || alert->low.warn_on)
-		alert->warn_repeat = alert->warn_repeat_set;
+	if (alert->alarm_command_entry)
+		{
+		spin = GTK_SPIN_BUTTON(alert->alarm_repeat_spin_button);
+		alert->alarm_repeat_set = gtk_spin_button_get_value_as_int(spin);
+
+		s = gkrellm_gtk_entry_get_text(&alert->alarm_command_entry);
+		gkrellm_dup_string(&alert->alarm_command, s);
+		if (!*s)
+			alert->alarm_repeat_set = 0;
+		if (alert->high.alarm_on || alert->low.alarm_on)
+			alert->alarm_repeat = alert->alarm_repeat_set;
+		}
+
+	if (alert->warn_command_entry)
+		{
+		spin = GTK_SPIN_BUTTON(alert->warn_repeat_spin_button);
+		alert->warn_repeat_set = gtk_spin_button_get_value_as_int(spin);
+
+		s = gkrellm_gtk_entry_get_text(&alert->warn_command_entry);
+		gkrellm_dup_string(&alert->warn_command, s);
+		if (!*s)
+			alert->warn_repeat_set = 0;
+		if (alert->high.warn_on || alert->low.warn_on)
+			alert->warn_repeat = alert->warn_repeat_set;
+		}
 
 	if (alert->voice_string_entry)
 		{
+		spin = GTK_SPIN_BUTTON(alert->voice_repeat_spin_button);
+		alert->voice_repeat_set = gtk_spin_button_get_value_as_int(spin);
+
 		s = gkrellm_gtk_entry_get_text(&alert->voice_string_entry);
 		gkrellm_dup_string(&alert->voice_string, s);
 		if (!*s)
@@ -886,8 +921,8 @@ cb_low_alarm_spin_changed(GtkWidget *adjustment, GkrellmAlert *alert)
 void
 gkrellm_alert_config_window(GkrellmAlert **alert)
 	{
-	GtkWidget	*main_vbox, *vbox, *vbox1, *hbox;
-	GtkWidget	*table;
+	GtkWidget	*main_vbox, *vbox, *vbox1 = NULL, *hbox;
+	GtkWidget	*table = NULL;
 	GtkWidget	*button;
 	GtkWidget	*label;
 	GtkWidget	*separator;
@@ -905,7 +940,9 @@ gkrellm_alert_config_window(GkrellmAlert **alert)
 				G_CALLBACK(alert_config_window_delete_event), alert);
 		gtk_window_set_title(GTK_WINDOW(ap->config_window),
 				_("GKrellM Set Alerts"));
-	
+		gtk_window_set_wmclass(GTK_WINDOW(ap->config_window),
+				"Gkrellm_conf", "Gkrellm");
+
 		gtk_container_set_border_width(GTK_CONTAINER(ap->config_window), 4);
 		main_vbox = gtk_vbox_new(FALSE, 0);
 		gtk_container_add(GTK_CONTAINER(ap->config_window), main_vbox);
@@ -925,7 +962,10 @@ gkrellm_alert_config_window(GkrellmAlert **alert)
 		w = 70;
 		if (ap->max_high > 100000)
 			w += log(ap->max_high / 100000) * 5;
-		if (ap->check_high)
+
+		ap->high.alarm_limit_spin_button = NULL;
+		ap->high.warn_limit_spin_button = NULL;
+		if (ap->check_high  && !ap->check_hardwired)
 			{
 			vbox1 = gkrellm_gtk_framed_vbox(hbox, _("High Limits"),
 						2, FALSE, 2,2);
@@ -942,7 +982,9 @@ gkrellm_alert_config_window(GkrellmAlert **alert)
 					_("High warn limit"));
 			}
 
-		if (ap->check_low)
+		ap->low.alarm_limit_spin_button = NULL;
+		ap->low.warn_limit_spin_button = NULL;
+		if (ap->check_low && !ap->check_hardwired)
 			{
 			vbox1 = gkrellm_gtk_framed_vbox_end(hbox, _("Low Limits"),
 					2, FALSE, 2, 2);
@@ -972,52 +1014,60 @@ gkrellm_alert_config_window(GkrellmAlert **alert)
 			(*ap->cb_config_create)(alert, vbox1, ap->cb_config_create_data);
 			}
 
-		vbox1 = gkrellm_gtk_framed_vbox(vbox,
-				_("Commands - with repeat intervals in seconds"),
-				2, FALSE, 2, 2);
+		if (ap->do_alarm_command || ap->do_warn_command)
+			{
+			vbox1 = gkrellm_gtk_framed_vbox(vbox,
+					_("Commands - with repeat intervals in seconds"),
+					2, FALSE, 2, 2);
+			table = gtk_table_new(3 /* across */, 3 /* down */, FALSE);
+			gtk_table_set_col_spacings(GTK_TABLE(table), 4);
+			gtk_box_pack_start(GTK_BOX(vbox1), table, FALSE, FALSE, 0);
+			}
 
-		table = gtk_table_new(3 /* across */, 3 /* down */, FALSE);
-		gtk_table_set_col_spacings(GTK_TABLE(table), 4);
-		gtk_box_pack_start(GTK_BOX(vbox1), table, FALSE, FALSE, 0);
+		ap->alarm_command_entry = ap->alarm_repeat_spin_button = NULL;
+		if (ap->do_alarm_command)
+			{
+			label = gtk_label_new(_("Alarm command:"));
+			gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
+			gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 0, 1);
+			ap->alarm_command_entry = gtk_entry_new();
+			gtk_entry_set_max_length(GTK_ENTRY(ap->alarm_command_entry), 255);
+			gtk_table_attach_defaults(GTK_TABLE(table),
+					ap->alarm_command_entry, 1, 2, 0, 1);
+			gtk_entry_set_text(GTK_ENTRY(ap->alarm_command_entry),
+					ap->alarm_command);
+			gkrellm_gtk_spin_button(NULL, &ap->alarm_repeat_spin_button,
+					ap->alarm_repeat_set, 0, 1000,
+					1, 10, 0, 60, NULL, NULL, FALSE, NULL);
+			gtk_table_attach_defaults(GTK_TABLE(table),
+					ap->alarm_repeat_spin_button, 2, 3, 0, 1);
+			}
 
-		if (!ap->alarm_command)
-			ap->alarm_command = g_strdup("");
-		label = gtk_label_new(_("Alarm command:"));
-		gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
-		gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 0, 1);
-		ap->alarm_command_entry = gtk_entry_new();
-		gtk_entry_set_max_length(GTK_ENTRY(ap->alarm_command_entry), 255);
-		gtk_table_attach_defaults(GTK_TABLE(table), ap->alarm_command_entry,
-				1, 2, 0, 1);
-		gtk_entry_set_text(GTK_ENTRY(ap->alarm_command_entry),
-				ap->alarm_command);
-		gkrellm_gtk_spin_button(NULL, &ap->alarm_repeat_spin_button,
-				ap->alarm_repeat_set, 0, 1000,
-				1, 10, 0, 60, NULL, NULL, FALSE, NULL);
-		gtk_table_attach_defaults(GTK_TABLE(table),
-				ap->alarm_repeat_spin_button, 2, 3, 0, 1);
+		ap->warn_command_entry = ap->warn_repeat_spin_button = NULL;
+		if (ap->do_warn_command)
+			{
+			label = gtk_label_new(_("Warn command:"));
+			gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
+			gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 1, 2);
+			ap->warn_command_entry = gtk_entry_new();
+			gtk_entry_set_max_length(GTK_ENTRY(ap->warn_command_entry), 255);
+			gtk_table_attach_defaults(GTK_TABLE(table), ap->warn_command_entry,
+					1, 2, 1, 2);
+			gtk_entry_set_text(GTK_ENTRY(ap->warn_command_entry),
+					ap->warn_command);
+			gtk_widget_set_size_request(ap->warn_command_entry, 300, -1);
+			gkrellm_gtk_spin_button(NULL, &ap->warn_repeat_spin_button,
+					ap->warn_repeat_set, 0, 1000,
+					1, 10, 0, 60, NULL, NULL, FALSE, NULL);
+			gtk_table_attach_defaults(GTK_TABLE(table),
+					ap->warn_repeat_spin_button, 2, 3, 1, 2);
+			}
 
-		if (!ap->warn_command)
-			ap->warn_command = g_strdup("");
-		label = gtk_label_new(_("Warn command:"));
-		gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
-		gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 1, 2);
-		ap->warn_command_entry = gtk_entry_new();
-		gtk_entry_set_max_length(GTK_ENTRY(ap->warn_command_entry), 255);
-		gtk_table_attach_defaults(GTK_TABLE(table), ap->warn_command_entry,
-				1, 2, 1, 2);
-		gtk_entry_set_text(GTK_ENTRY(ap->warn_command_entry),
-				ap->warn_command);
-		gtk_widget_set_size_request(ap->warn_command_entry, 300, -1);
-		gkrellm_gtk_spin_button(NULL, &ap->warn_repeat_spin_button,
-				ap->warn_repeat_set, 0, 1000,
-				1, 10, 0, 60, NULL, NULL, FALSE, NULL);
-		gtk_table_attach_defaults(GTK_TABLE(table),
-				ap->warn_repeat_spin_button, 2, 3, 1, 2);
-
-		if (!ap->voice_string)
-			ap->voice_string = g_strdup("");
-		if (gvoice_fifo_open())
+		ap->voice_string_entry = NULL;
+		ap->voice_repeat_spin_button = NULL;
+		if (   (ap->do_alarm_command || ap->do_warn_command)
+			&& gvoice_fifo_open()
+		   )
 			{
 			label = gtk_label_new(_("Voice string:"));
 			gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
@@ -1035,20 +1085,18 @@ gkrellm_alert_config_window(GkrellmAlert **alert)
 			gtk_table_attach_defaults(GTK_TABLE(table),
 					ap->voice_repeat_spin_button, 2, 3, 2, 3);
 			}
-		else
+
+		if (ap->do_alarm_command || ap->do_warn_command)
 			{
-			ap->voice_string_entry = NULL;
-			ap->voice_repeat_spin_button = NULL;
-			}
+			separator = gtk_hseparator_new();
+			gtk_box_pack_start(GTK_BOX(vbox1), separator, FALSE, FALSE, 4);
 
-		separator = gtk_hseparator_new();
-		gtk_box_pack_start(GTK_BOX(vbox1), separator, FALSE, FALSE, 4);
-
-		label = gtk_label_new(
+			label = gtk_label_new(
 		   _("A repeat of zero seconds executes the command once per alert."));
-		gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-		gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT);
-		gtk_box_pack_start(GTK_BOX(vbox1), label, FALSE, FALSE, 0);
+			gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+			gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT);
+			gtk_box_pack_start(GTK_BOX(vbox1), label, FALSE, FALSE, 0);
+			}
 
 		hbox = gtk_hbutton_box_new();
 		gtk_button_box_set_layout(GTK_BUTTON_BOX(hbox), GTK_BUTTONBOX_END);
@@ -1108,7 +1156,7 @@ gkrellm_save_alertconfig(FILE *f, GkrellmAlert *alert,
 	if (alert->voice_string && *alert->voice_string)
 		fprintf(f, "%s voice_string %s\n", s, alert->voice_string);
 	fprintf(f, "%s values %d %d %d %d\n", s, alert->do_panel_updates,
-			alert->check_high, alert->check_low, alert->check_boolean);
+			alert->check_high, alert->check_low, alert->check_hardwired);
 	fprintf(f, "%s repeat %d %d %d\n", s, alert->alarm_repeat_set,
 			alert->warn_repeat_set, alert->voice_repeat_set);
 	fprintf(f, "%s limits %.2f %.2f %.2f %.2f\n", s,
@@ -1146,7 +1194,7 @@ gkrellm_load_alertconfig(GkrellmAlert **ap, gchar *config_line)
 		gkrellm_dup_string(&alert->voice_string, item);
 	else if (!strcmp(config, "values"))
 		sscanf(item, "%d %d %d %d", &alert->do_panel_updates,
-				&alert->check_high, &alert->check_low, &alert->check_boolean);
+			&alert->check_high, &alert->check_low, &alert->check_hardwired);
 	else if (!strcmp(config, "delay"))
 		{
 		sscanf(item, "%d %d %d %d", &n,
