@@ -42,9 +42,9 @@ typedef struct
 	{
 	gint				id;
 	GkrellmPanel		*panel;
-	GkrellmKrell		*battery_krell;
-	GkrellmDecal		*power_source_decal;
-	GkrellmDecal		*minutes_left_decal;
+	GkrellmKrell		*krell;
+	GkrellmDecal		*power_decal;
+	GkrellmDecal		*time_decal;
 
 	GkrellmAlert		*alert;
 
@@ -88,17 +88,20 @@ static Battery *
 battery_nth(gint n)
 	{
 	Battery		*bat;
+	static gint	n_batteries;
 
-	if ((bat = (Battery *)g_list_nth_data(battery_list, n)) == NULL)
+	if (n < 0 || n > 10)
+		return NULL;
+	while ((bat = (Battery *)g_list_nth_data(battery_list, n)) == NULL)
 		{
 		bat = g_new0(Battery, 1);
 		battery_list = g_list_append(battery_list, bat);
-		bat->id = n;
+		bat->id = n_batteries++;
 		}
 	return bat;
 	}
 
-/* ------- Demo ------------------------------------------------------- */
+
   /* Themers need to be able to see the battery monitor.
   */
 static void
@@ -156,6 +159,8 @@ gkrellm_battery_assign_data(gint n, gboolean present, gboolean on_line,
 	Battery	*bat;
 
 	bat = battery_nth(n);
+	if (!bat)
+		return;
 	bat->present = present;
 	bat->on_line = on_line;
 	bat->charging = charging;
@@ -171,6 +176,9 @@ gkrellm_battery_full_cap_fallback(void)
 	return full_cap_fallback;
 	}
 
+
+/* -------------------------------------------------------------- */
+
 /* estimate (guess-timate?) battery time remaining, based on the rate of 
    discharge (and conversely the time to charge based on the rate of charge).
   - some BIOS' only provide battery levels, not any estimate of the time
@@ -232,8 +240,6 @@ gkrellm_battery_full_cap_fallback(void)
     Furthermore, the rate changes are windowed and filtered to mitigate 
     c(t) transients (e.g. at the start of discharge) and smooth over 
     discontinuities (and fudge for battery characteristics, ref. above).
-
- 
 */
 
 #define BAT_SLEEP_DETECT 300		/* interval of >300s => must have slept */
@@ -265,14 +271,13 @@ estimate_battery_time_left(Battery *bat)
 	time_t			t = time(NULL);
 
 	/* 1 charging; 0 power on and stable; -1 discharging */
-	gint			charging = bat->charging ? 1 : 
-							(bat->on_line ? 0 : -1);
+	gint			charging = bat->charging ? 1 : (bat->on_line ? 0 : -1);
 
-#		ifdef BAT_ESTIMATE_DEBUG
+#ifdef BAT_ESTIMATE_DEBUG
 		fprintf(stderr, "%ld bc?=%d ac?=%d (%+d) bp=%d\t", t, 
 			bat->charging, bat->on_line, charging, 
 			bat->percent);
-#		endif
+#endif
 
 	if (   reset_estimate || t0 < 0 || c0 != charging
 		|| (t - t1) > BAT_SLEEP_DETECT
@@ -284,27 +289,28 @@ estimate_battery_time_left(Battery *bat)
 		c0 = charging;
 
 		t0 = t1 = t;
-		if (charging < 0 && 
-				(bat->percent > 100 - BAT_DISCHARGE_TRANSIENT))
+		if (charging < 0 && (bat->percent > 100 - BAT_DISCHARGE_TRANSIENT))
 			p0 = p1 = 100 - BAT_DISCHARGE_TRANSIENT;
 		else
 			p0 = p1 = bat->percent;
 		dp = dt = 0;
 		rate = 0.0;
-		/* convert runtime (hrs) to signed rate (%/min) */
-		if		(charging < 0)
-			rate = -100/(estimate_runtime[0] * 60);
-		else if (charging > 0)
-			rate =  100/(estimate_runtime[1] * 60);
 
-#		ifdef BAT_ESTIMATE_DEBUG
+		/* convert runtime (hrs) to signed rate (%/min)
+		*/
+		if (charging < 0)
+			rate = -100 / (estimate_runtime[0] * 60);
+		else if (charging > 0)
+			rate =  100 / (estimate_runtime[1] * 60);
+
+#ifdef BAT_ESTIMATE_DEBUG
 		fprintf(stderr, "[r = %.3f]\t", rate);
-#		endif
+#endif
 		}
 	else
 		{
-		time_t dt1 = t - t1; /* delta since last rate change */
-		gint dp1 = bat->percent - p1;
+		time_t	dt1 = t - t1;		/* delta since last rate change */
+		gint	dp1 = bat->percent - p1;
 
 		/* time for a rate change?
 		*/
@@ -316,22 +322,16 @@ estimate_battery_time_left(Battery *bat)
 			dp = bat->percent - p0;
 
 			if (dp1 == 0)	/* flatlining (dp/dt = 0) */
-				{
-#				ifdef BAT_ESTIMATE_DEBUG
-				fprintf(stderr, "F");
-#				endif
-				rate = (1-BAT_RATE_SMOOTHING/4) * rate;
-				}
+				rate = (1 - BAT_RATE_SMOOTHING/4) * rate;
 			else
-				{
-				rate = BAT_RATE_SMOOTHING * ((gdouble) dp / (gdouble) (dt/60)) + 
-					(1-BAT_RATE_SMOOTHING) * rate;
-				}
+				rate = BAT_RATE_SMOOTHING *
+						((gdouble) dp / (gdouble) (dt/60)) + 
+						(1 - BAT_RATE_SMOOTHING) * rate;
 
-#			ifdef BAT_ESTIMATE_DEBUG
-			fprintf(stderr, "[dp = %+d dt = %.2f rate = %.3f]\t", dp, 
-					(gdouble)dt/60, rate);
-#			endif
+#ifdef BAT_ESTIMATE_DEBUG
+			fprintf(stderr, "%d [dp = %+d dt = %.2f rate = %.3f]\t",
+					(gint) dp1, dp, (gdouble) dt / 60, rate);
+#endif
 
 			t1 = t;
 			p1 = bat->percent;
@@ -340,12 +340,9 @@ estimate_battery_time_left(Battery *bat)
 
 	if (charging && rate != 0.0)	/* (dis)charging */
 		{
-		gfloat eta;	/* "estimated time of arrival", minutes */
-
-		/* estimated percentage (capacity) remaining (to full/empty)
-		*/
-		gint p = charging > 0 ? 100 - bat->percent : 
-					bat->percent - BAT_EMPTY_CAPACITY;
+		gfloat	eta;
+		gint 	p = charging > 0 ? 100 - bat->percent : 
+						bat->percent - BAT_EMPTY_CAPACITY;
 
 		if (   charging > 0 && estimate_model[1]
 			&& bat->percent < BAT_CHARGE_MODEL_LIMIT && dp > 0
@@ -355,9 +352,9 @@ estimate_battery_time_left(Battery *bat)
 		else
 			eta = abs((gdouble)p / rate);	/* use linear */
 
-#		ifdef BAT_ESTIMATE_DEBUG
+#ifdef BAT_ESTIMATE_DEBUG
 		fprintf(stderr, "eta = %.2f\t", eta);
-#		endif
+#endif
 
 		/* round off to nearest 5 mins */
 		bat->time_left = (gint)((eta > 0 ? eta + 2.5: 0) / 5) * 5;
@@ -369,9 +366,9 @@ estimate_battery_time_left(Battery *bat)
 		bat->charge_rate = 0.0;
 		}
 
-#		ifdef BAT_ESTIMATE_DEBUG
+#ifdef BAT_ESTIMATE_DEBUG
 		fprintf(stderr, "\n");
-#		endif
+#endif
 	}
 
 static void
@@ -413,7 +410,7 @@ draw_time_left_decal(Battery *bat, gboolean force)
 			break;
 		}
 
-	d = bat->minutes_left_decal;
+	d = bat->time_decal;
 	w = gkrellm_gdk_string_width(d->text_style.font, buf);
 	x = (d->w - w) / 2;
 	if (x < 0)
@@ -425,41 +422,40 @@ draw_time_left_decal(Battery *bat, gboolean force)
 static void
 update_battery_panel(Battery *bat)
 	{
+	GkrellmPanel	*p  = bat->panel;
+
 	if (!bat->present)
 		{	/* Battery can be removed while running */
-		bat->percent = 0;
-		}
-	else if (bat->time_left > 0 && bat->charging)
-		{
-		bat->charge_rate = (gfloat) bat->percent / 
-				(gfloat) bat->time_left;
+		gkrellm_panel_hide(p);
+		return;
 		}
+	gkrellm_panel_show(p);
+
+	if (bat->time_left > 0 && bat->charging)
+		bat->charge_rate = (gfloat) bat->percent / (gfloat) bat->time_left;
 	else
 		bat->charge_rate = 0.0;
 
-	if (enable_estimate && bat->present)
+	if (enable_estimate)
 		estimate_battery_time_left(bat);
 
-	gkrellm_check_alert(bat->alert, alert_units_are_percent
-				? bat->percent : bat->time_left);
-	if (bat->on_line || !bat->present)
+	if (bat->on_line)
 		{
 		gkrellm_reset_alert(bat->alert);
 		gkrellm_freeze_alert(bat->alert);
-		gkrellm_draw_decal_pixmap(bat->panel,
-				bat->power_source_decal,
-				bat->present ? D_MISC_AC : D_MISC_BLANK);
+		gkrellm_draw_decal_pixmap(p, bat->power_decal, D_MISC_AC);
 		}
 	else
 		{
 		gkrellm_thaw_alert(bat->alert);
-		gkrellm_draw_decal_pixmap(bat->panel,
-				bat->power_source_decal, D_MISC_BATTERY);
+		gkrellm_check_alert(bat->alert, alert_units_are_percent
+					? bat->percent : bat->time_left);
+		gkrellm_draw_decal_pixmap(p, bat->power_decal, D_MISC_BATTERY);
 		}
 	draw_time_left_decal(bat, FALSE);
 
-	gkrellm_update_krell(bat->panel, bat->battery_krell, bat->percent);
-	gkrellm_draw_panel_layers(bat->panel);
+	gkrellm_update_krell(p, bat->krell, bat->percent);
+	gkrellm_draw_panel_layers(p);
 	}
 
 static void
@@ -473,6 +469,9 @@ update_battery(void)
 		{
 		if (enable_battery && (seconds == 0))
 			{
+			for (list = battery_list; list; list = list->next)
+				((Battery *) list->data)->present = FALSE;
+
 			(*read_battery_data)();
 			for (list = battery_list; list; list = list->next)
 				{
@@ -499,7 +498,7 @@ cb_expose_event(GtkWidget *widget, GdkEventExpose *ev, GkrellmPanel *p)
 static gboolean
 cb_panel_enter(GtkWidget *w, GdkEventButton *ev, Battery *bat)
 	{
-	gkrellm_decal_on_top_layer(bat->minutes_left_decal, TRUE);
+	gkrellm_decal_on_top_layer(bat->time_decal, TRUE);
 	gkrellm_draw_panel_layers(bat->panel);
 	return FALSE;
 	}
@@ -507,7 +506,7 @@ cb_panel_enter(GtkWidget *w, GdkEventButton *ev, Battery *bat)
 static gboolean
 cb_panel_leave(GtkWidget *w, GdkEventButton *ev, Battery *bat)
 	{
-	gkrellm_decal_on_top_layer(bat->minutes_left_decal, FALSE);
+	gkrellm_decal_on_top_layer(bat->time_decal, FALSE);
 	gkrellm_draw_panel_layers(bat->panel);
 	return FALSE;
 	}
@@ -563,32 +562,30 @@ create_battery_panel(Battery *bat, gboolean first_create)
 	p = bat->panel;
 	style = gkrellm_meter_style(style_id);
 	m = gkrellm_get_style_margins(style);
-	bat->power_source_decal = gkrellm_create_decal_pixmap(p,
+	bat->power_decal = gkrellm_create_decal_pixmap(p,
 			gkrellm_decal_misc_pixmap(), gkrellm_decal_misc_mask(),
 			N_MISC_DECALS, style, m->left, -1);
 
-	x = bat->power_source_decal->x + bat->power_source_decal->w + 2;
+	x = bat->power_decal->x + bat->power_decal->w + 2;
 	w = gkrellm_chart_width() - x - m->right;
-	bat->minutes_left_decal = gkrellm_create_decal_text(p, "8/%",
+	bat->time_decal = gkrellm_create_decal_text(p, "8/%",
 						gkrellm_meter_textstyle(style_id),
 						style, x, -1, w);
 
-	bat->battery_krell = gkrellm_create_krell(p,
+	bat->krell = gkrellm_create_krell(p,
 						gkrellm_krell_meter_piximage(style_id), style);
-	gkrellm_monotonic_krell_values(bat->battery_krell, FALSE);
-	gkrellm_set_krell_full_scale(bat->battery_krell, 100, 1);
+	gkrellm_monotonic_krell_values(bat->krell, FALSE);
+	gkrellm_set_krell_full_scale(bat->krell, 100, 1);
 
 	gkrellm_panel_configure(p, NULL, style);
 	gkrellm_panel_create(battery_vbox, mon_battery, p);
 
 	/* Center the decals with respect to each other.
 	*/
-	if (bat->power_source_decal->h > bat->minutes_left_decal->h)
-		bat->minutes_left_decal->y +=
-				(bat->power_source_decal->h - bat->minutes_left_decal->h) / 2;
+	if (bat->power_decal->h > bat->time_decal->h)
+		bat->time_decal->y += (bat->power_decal->h - bat->time_decal->h) / 2;
 	else
-		bat->power_source_decal->y +=
-				(bat->minutes_left_decal->h - bat->power_source_decal->h) / 2;
+		bat->power_decal->y += (bat->time_decal->h - bat->power_decal->h) / 2;
 
 	if (first_create)
 		{
@@ -602,7 +599,7 @@ create_battery_panel(Battery *bat, gboolean first_create)
                 G_CALLBACK(cb_panel_leave), bat);
 		 }
 	if (bat->id == 0)
-		gkrellm_setup_decal_launcher(p, &launch, bat->minutes_left_decal);
+		gkrellm_setup_decal_launcher(p, &launch, bat->time_decal);
 
 	bat->enabled = enable_battery;
 	if (bat->enabled)
@@ -646,6 +643,55 @@ create_battery(GtkWidget *vbox, gint first_create)
 	spacer_visibility();
 	}
 
+
+  /* Expand alert command substitution variables:
+  |  $H - hostname           $n - battery id
+  |  $t - time left          $p - percent
+  |  $o - online (boolean)   $c - charging (boolean)
+  */
+static void
+cb_command_process(GkrellmAlert *alert, gchar *src, gchar *buf, gint size,
+			Battery *bat)
+	{
+	gchar		c, *s;
+	gint		len, value;
+
+	if (!buf || size < 1)
+		return;
+	--size;
+	*buf = '\0';
+	if (!src)
+		return;
+	for (s = src; *s != '\0' && size > 0; ++s)
+		{
+		len = 1;
+		if (*s == '$' && *(s + 1) != '\0')
+			{
+			value = -1;
+			if ((c = *(s + 1)) == 'H')
+				len = snprintf(buf, size, "%s", gkrellm_sys_get_host_name());
+			else if (c == 'n')
+				value = bat->id;
+			else if (c == 't')
+				value = bat->time_left;
+			else if (c == 'p')
+				value = bat->percent;
+			else if (c == 'o')
+				value = bat->on_line;
+			else if (c == 'c')
+				value = bat->charging;
+			if (value >= 0)
+				len = snprintf(buf, size, "%d", value);
+			++s;
+			}
+		else
+			*buf = *s;
+		size -= len;
+		buf += len;
+		}
+	*buf = '\0';
+	}
+
 static void
 cb_battery_alert_trigger(GkrellmAlert *alert, Battery *bat)
 	{
@@ -654,7 +700,7 @@ cb_battery_alert_trigger(GkrellmAlert *alert, Battery *bat)
 
 	alert->panel = bat->panel;
 	ad = &alert->ad;
-	d = bat->minutes_left_decal;
+	d = bat->time_decal;
 	ad->x = d->x + 1;
 	ad->y = d->y - 2;
 	ad->w = d->w - 1;
@@ -698,6 +744,8 @@ create_battery_alert(Battery *bat, gboolean using_percent)
 		}
 	gkrellm_alert_trigger_connect(bat->alert,
 				cb_battery_alert_trigger, bat);
+	gkrellm_alert_command_process_connect(bat->alert,
+				cb_command_process, bat);
 	}
 
 
@@ -720,7 +768,8 @@ save_battery_config(FILE *f)
 				estimate_model[1]);
 	fprintf(f, "%s full_cap_fallback %d\n", BAT_CONFIG_KEYWORD,
 						full_cap_fallback);
-	fprintf(f, "%s poll_interval %d\n", BAT_CONFIG_KEYWORD, poll_interval);
+	if (!_GK.client_mode)
+		fprintf(f, "%s poll_interval %d\n", BAT_CONFIG_KEYWORD, poll_interval);
 	if (launch.command)
 		fprintf(f, "%s launch1 %s\n", BAT_CONFIG_KEYWORD, launch.command);
 	if (launch.tooltip_comment)
@@ -994,12 +1043,15 @@ create_battery_tab(GtkWidget *tab_vbox)
 			_("Exponential charge model"));
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox2, FALSE, FALSE, 0);
 
-	hbox2 = gtk_hbox_new(FALSE, 10);
-	gkrellm_gtk_spin_button(hbox2, NULL,
-			(gfloat) poll_interval, 1, 3600, 1, 10, 0, 55,
-			cb_poll_interval, NULL, FALSE,
-			_("Seconds between updates"));
-	gtk_box_pack_end(GTK_BOX(vbox), hbox2, FALSE, FALSE, 6);
+	if (!_GK.client_mode)
+		{
+		hbox2 = gtk_hbox_new(FALSE, 10);
+		gkrellm_gtk_spin_button(hbox2, NULL,
+				(gfloat) poll_interval, 1, 3600, 1, 10, 0, 55,
+				cb_poll_interval, NULL, FALSE,
+				_("Seconds between updates"));
+		gtk_box_pack_end(GTK_BOX(vbox), hbox2, FALSE, FALSE, 6);
+		}
 
 	vbox = gkrellm_gtk_framed_notebook_page(tabs, _("Setup"));
 	hbox = gtk_hbox_new(FALSE, 0);
@@ -1073,7 +1125,11 @@ init_battery_monitor(void)
 	enable_estimate = FALSE;	/* use the BIOS value */
 	estimate_runtime[0] =  1.5;	/* 1.5 hour battery */
 	estimate_runtime[1] =	3.0;	/* 3 hour recharge */
+	if (_GK.client_mode)
+		poll_interval = 1;
+
 	monitor_battery.name=_(monitor_battery.name);
+
 	style_id = gkrellm_add_meter_style(&monitor_battery, BATTERY_STYLE_NAME);
 	mon_battery = &monitor_battery;
 	if (setup_battery_interface())
