@@ -22,6 +22,8 @@
 #include "gkrellm.h"
 #include "gkrellm-private.h"
 
+#include <math.h>
+
   /* For grid images of height 2 pixels, make room at bottom of chartdata
   |  window so both pixel lines will show.
   */
@@ -248,10 +250,19 @@ static gint
 chartdata_ycoord(GkrellmChart *cp, GkrellmChartdata *cd, gint yd)
 	{
 	glong	y;
+	guint64	Y;
 	
 	if (cp->scale_max <= 0)
 		cp->scale_max = 1;
-	y = ((glong) yd * cd->h / cp->scale_max);
+
+	if (yd > 2000000000 / MAX_CHARTHEIGHT)
+		{
+		Y = (guint64) yd * (guint64) cd->h;
+		y = Y / cp->scale_max;
+		}
+	else
+		y = ((glong) yd * cd->h / cp->scale_max);
+
 	if (y < 0)
 		y = 0;
 	if (y >= cd->h)
@@ -485,15 +496,7 @@ draw_chartdata_lines(GkrellmChart *cp, GkrellmChartdata *cd, gint i0)
 		}
 	}
 
-  /* Keep a maxval_auto_base that is 1/5 (1/FULL_SCALE_GRIDS) the peak maxval.
-  |  * If using a fixed grid, auto resolution means set the resolution/grid to
-  |    the smallest value in base to peak range (rounded up in resolution
-  |    table) that draws data without clipping.
-  |  * If using auto grids, auto resolution means set resolution to
-  |    maxval_auto_base (rounded down in resolution table) so drawing peak
-  |    valued data requires at least 5 (FULL_SCALE_GRIDS) grids.  Rounding
-  |    down gives some tolerance to spurious data spikes which can set the
-  |    base resolution too high.
+  /* See the README for description of auto grid resolution behavior.
   */
 static void
 set_auto_grid_resolution(GkrellmChart *cp, gint maxval)
@@ -515,7 +518,7 @@ set_auto_grid_resolution(GkrellmChart *cp, gint maxval)
 	cp->maxval_auto = maxval;
 
 	grids = cf->fixed_grids;
-	if (!grids)		/* Auto grids mode */
+	if (grids == 0)		/* Auto grids mode */
 		grid_res = gkrellm_125_sequence(cp->maxval_auto_base, cf->sequence_125,
 					cf->low, cf->high, TRUE, FALSE);
 	else
@@ -533,6 +536,17 @@ set_auto_grid_resolution(GkrellmChart *cp, gint maxval)
 			(*cf->cb_grid_resolution)(cf, cf->cb_grid_resolution_data);
 		cp->redraw_all = TRUE;
 		}
+	cp->auto_recalibrate_delay = 0;
+	}
+
+static gboolean
+auto_recalibrate(GkrellmChart *cp)
+	{
+	if (++cp->auto_recalibrate_delay < 10)
+		return FALSE;
+	cp->maxval_peak = 0;
+	cp->maxval_auto_base = 0;
+	return TRUE;
 	}
 
 static gint
@@ -546,13 +560,24 @@ setup_chart_scalemax(GkrellmChart *cp)
 	|  draw compute a scalemax and compare to last cp->scale_max.
 	|  Redraw grided background if different.
 	*/
-	if (   cf->auto_grid_resolution
-		&& cp->maxval != cp->maxval_auto
-		&& (   cp->maxval > cp->maxval_auto
-			|| cp->maxval_auto != cp->maxval_auto_base
+	if (cf->auto_grid_resolution)
+		{
+		if (   cp->maxval != cp->maxval_auto
+			&& (   cp->maxval > cp->maxval_auto
+				|| cp->maxval_auto != cp->maxval_auto_base
+			   )
 		   )
-	   )
-		set_auto_grid_resolution(cp, cp->maxval);
+			set_auto_grid_resolution(cp, cp->maxval);
+		else if (   !cf->auto_resolution_stick
+				 && cp->maxval < cp->maxval_auto_base / FULL_SCALE_GRIDS
+				)
+			{
+			if (auto_recalibrate(cp))
+				set_auto_grid_resolution(cp, cp->maxval);
+			}
+		else
+			cp->auto_recalibrate_delay = 0;
+		}
 	grid_res = cf->grid_resolution;
 	if (cf->fixed_grids)
 		scalemax = grid_res * cf->fixed_grids;
@@ -1927,7 +1952,8 @@ gkrellm_chartconfig_grid_resolution_adjustment(GkrellmChartconfig *cf,
 	if (!cf)
 		return;
 	cf->map_sequence = map_sequence;
-	cf->width = width;
+	if ((cf->width = width) == 0)
+		cf->width = 70 + log(high / 100000) * 5;
 	if (map_sequence)
 		{
 		cf->low = 1;
@@ -2104,19 +2130,10 @@ set_resolution_menubar_items_sensitivity(GkrellmChartconfig *cf)
 
 	if (!cf->auto_resolution_item_factory)
 		return;
+
 	w = gtk_item_factory_get_widget(cf->auto_resolution_item_factory,
 				_("/Control/Auto mode sticks at peak value"));
-	if (cf->fixed_grids && cf->auto_grid_resolution)
-		{
-		GTK_CHECK_MENU_ITEM(w)->active = cf->auto_resolution_stick;
-		gtk_widget_set_sensitive(w, TRUE);
-		}
-	else	/* Auto number of grids, auto res always sticks at base value */
-		{
-		GTK_CHECK_MENU_ITEM(w)->active = cf->fixed_grids ?
-				cf->auto_resolution_stick : FALSE;
-		gtk_widget_set_sensitive(w, FALSE);
-		}
+	GTK_CHECK_MENU_ITEM(w)->active = cf->auto_resolution_stick;
 
 	w = gtk_item_factory_get_widget(cf->auto_resolution_item_factory,
 				_("/Control/Auto mode recalibrate"));
@@ -2238,10 +2255,11 @@ cb_auto_res_control(GkrellmChart *cp, guint option, GtkWidget* widget)
         case 0:
 			cp->maxval_auto_base = 0;
 			cp->maxval_peak = 0;
-            break;
+			break;
         case 1:
             active = GTK_CHECK_MENU_ITEM(widget)->active;
 			cf->auto_resolution_stick = active;
+			cp->maxval_auto_base = 0;
             break;
         case 2:
             active = GTK_CHECK_MENU_ITEM(widget)->active;
@@ -2342,7 +2360,9 @@ gkrellm_chartconfig_window_create(GkrellmChart *cp)
 	else
 		s = NULL;
 	gtk_window_set_title(GTK_WINDOW(cp->config_window),
-			_("GKrellM Chart Config"));
+				_("GKrellM Chart Config"));
+	gtk_window_set_wmclass(GTK_WINDOW(cp->config_window),
+				"Gkrellm_conf", "Gkrellm");
 
 	main_vbox = gtk_vbox_new(FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(cp->config_window), 4);
