@@ -835,41 +835,83 @@ client_fs_setup(gchar *line)
 	}
 
 /* ================================================================= */
-/* Need to handle more than one battery. */
+GList		*battery_list;
 
-struct
+gboolean 	batteries_available;
+
+typedef struct
 	{
-    gboolean	battery_is_available,
-				ac_is_on_line,
-				battery_is_charging;
-	gint		battery_percentage;
-	gint		battery_time_left;
+	gint		id;
+    gboolean	present,
+				on_line,
+				charging;
+	gint		percent;
+	gint		time_left;
+	}
+	Battery;
+
+
+static Battery *
+battery_nth(gint n)
+	{
+	Battery		*bat;
+	static gint	n_batteries;
+
+	if (n < 0 || n > 10)
+		return NULL;
+	while ((bat = (Battery *)g_list_nth_data(battery_list, n)) == NULL)
+		{
+		bat = g_new0(Battery, 1);
+		battery_list = g_list_append(battery_list, bat);
+		bat->id = n_batteries++;
+		}
+	return bat;
 	}
-	bat;
 
 
 static void
 client_battery_line_from_server(gchar *line)
 	{
-	sscanf(line, "%d %d %d %d %d", &bat.battery_is_available,
-				&bat.ac_is_on_line, &bat.battery_is_charging,
-				&bat.battery_percentage, &bat.battery_time_left);
+	Battery		*bat;
+	gboolean	present, on_line, charging;
+	gint		percent, time_left, n = 0;
+
+	/* 2.1.9 adds 6th arg battery id number
+	*/
+	if (sscanf(line, "%d %d %d %d %d %d",
+				&present, &on_line, &charging, &percent, &time_left, &n) < 5)
+		return;
+
+	bat = battery_nth(n);
+	if (!bat)
+		return;
+	bat->present = present;
+	bat->on_line = on_line;
+	bat->charging = charging;
+	bat->percent = percent;
+	bat->time_left = time_left;
 	}
 
 static void
 read_battery_data(void)
 	{
-	gkrellm_battery_assign_data(0, bat.battery_is_available,
-				bat.ac_is_on_line, bat.battery_is_charging,
-				bat.battery_percentage, bat.battery_time_left);
+	GList	*list;
+	Battery	*bat;
+
+	for (list = battery_list; list; list = list->next)
+		{
+		bat = (Battery *) list->data;
+		gkrellm_battery_assign_data(bat->id, bat->present,
+				bat->on_line, bat->charging,
+				bat->percent, bat->time_left);
+		}
 	}
 
 static void
 client_sys_battery_init(void)
 	{
-	if (!bat.battery_is_available)
-		return;
-	gkrellm_battery_client_divert(read_battery_data);
+	if (batteries_available)
+		gkrellm_battery_client_divert(read_battery_data);
 	}
 
 static void
@@ -878,7 +920,7 @@ client_battery_setup(gchar *line)
 	if (   !strcmp(line, "apm_available")
 		|| !strcmp(line, "battery_available")
 	   )
-		bat.battery_is_available = TRUE;
+		batteries_available = TRUE;
 	}
 
 /* ================================================================= */
