@@ -1009,9 +1009,40 @@ default_theme_extension_piximage(gchar *name, gchar *subdir)
 	return im;
 	}
 
+gboolean
+gkrellm_load_piximage_from_inline(gchar *name, const guint8 *data,
+			GkrellmPiximage **image, gchar *subdir, gboolean copy_pixels)
+	{
+	GkrellmPiximage	*im		= NULL;
+	gchar			*fname;
+
+	if (gkrellm_using_default_theme() && name && subdir)
+		im = default_theme_extension_piximage(name, subdir);
+	else if (name && (fname = gkrellm_theme_file_exists(name, subdir)) != NULL)
+		{
+		name = fname;
+		im = gkrellm_piximage_new_from_file(fname);
+		if (im == NULL)
+			printf(_("  Cannot load file image: %s\n"), fname);
+		}
+	if (im == NULL && data)
+		{
+		im = gkrellm_piximage_new_from_inline(data, copy_pixels);
+		if (im == NULL)
+			printf(_("  Cannot load GdkPixbuf inline data.\n"));
+		}
+	if (im && image)
+		{
+		if (*image)
+			gkrellm_destroy_piximage(*image);
+		*image = im;
+		}
+	return (im ? TRUE : FALSE);
+    }
+
 gboolean
 gkrellm_load_piximage(gchar *name, gchar **xpm, GkrellmPiximage **image,
-		gchar *subdir)
+			gchar *subdir)
 	{
 	GkrellmPiximage	*im		= NULL;
 	gchar			*fname;
@@ -2228,7 +2259,6 @@ struct	_config	user_config[] =
 
 	{"update_HZ",		&_GK.update_HZ,			NULL,	0  },
 	{"allow_multiple_instances", &_GK.allow_multiple_instances,	NULL,	0  },
-	{"set_wm_state_hack", &_GK.set_wm_state_hack,	NULL,	0  }
 	};
 
   /* The user_config is read twice.  Early to load _GK config values and then
