@@ -677,7 +677,7 @@ adjust_sensors_display(CpuMon *cpu, gint force)
 	|  is changed.  The alert will just retrigger at next fan update.
 	*/
 	alert = gkrellm_sensor_alert(cpu->sensor_fan);
-	gkrellm_reset_alert(alert);
+	gkrellm_reset_alert_soft(alert);
 
 	if (cpu->sensor_temp || _GK.demo)
 		cpu->show_temperature = TRUE;
