@@ -2026,10 +2026,7 @@ cb_delete(GtkWidget *widget)
 	gtk_tree_model_get_iter(model, &iter, path);
 
 	gtk_tree_model_get(model, &iter, FSMON_COLUMN, &fs, -1);
-	gkrellm_reset_alert(fs->alert);
-	if (fs->alert)
-		g_free(fs->alert);
-	fs->alert = NULL;
+	gkrellm_alert_destroy(&fs->alert);
 
 	gtk_tree_store_remove(GTK_TREE_STORE(model), &iter);
 	reset_entries(FALSE);
