@@ -41,6 +41,7 @@ struct	GkrellmConfig
 	gint		debug_level;
 	gint		demo;
 	gint		test;
+	gboolean	nolock;
 
 	gint		up_minutes;
 	gint		base_uptime;
@@ -118,8 +119,6 @@ struct	GkrellmConfig
 				decorated,
 				command_line_decorated;	/* Will override decorated */
 
-	gboolean	set_wm_state_hack;	/* Temporary aid for net_wm_state bugs */
-
 	gboolean	enable_hostname,		/* No separate hostname config. */
 				hostname_short,
 				enable_system_name;
@@ -317,6 +316,7 @@ GkrellmMonitor *gkrellm_get_sensors_mon(void);
 
 void	init_hostname_monitor(void);	/* XXX */
 GkrellmMonitor	*gkrellm_mon_host(void);
+void			cb_gkrellmd_disconnect_alert(GtkWidget *b, gpointer data);
 
 GList	*gkrellm_get_chart_list(void);
 GList	*gkrellm_get_panel_list(void);
@@ -365,6 +365,8 @@ gint	x_label_position(gint, gint, gint, gint);
 void	load_inet_data(void);
 void	save_inet_data(void);
 
+void	save_net_data(void);
+
 gint	effect_string_value(gchar *);
 
 void	map_color_string(gchar *, GdkColor *);
