@@ -240,6 +240,10 @@ void		gkrellm_destroy_button(GkrellmDecalbutton *);
   */
 gboolean	gkrellm_load_piximage(gchar *, gchar **,
 						GkrellmPiximage **, gchar *);
+gboolean	gkrellm_load_piximage_from_inline(gchar *, const guint8 *,
+						GkrellmPiximage **, gchar *, gboolean);
+GkrellmPiximage *gkrellm_piximage_new_from_inline(const guint8 *data,
+						gboolean);
 GkrellmPiximage	*gkrellm_piximage_new_from_file(gchar *fname);
 GkrellmPiximage	*gkrellm_piximage_new_from_xpm_data(gchar **data);
 void		gkrellm_set_piximage_border(GkrellmPiximage *piximage,
@@ -320,7 +324,8 @@ GkrellmAlert *gkrellm_alert_create(GkrellmPanel *, gchar *, gchar *,
 void		gkrellm_alert_dup(GkrellmAlert **a_dst, GkrellmAlert *a_src);
 void		gkrellm_alert_destroy(GkrellmAlert **);
 void		gkrellm_check_alert(GkrellmAlert *, gfloat);
-void		gkrellm_reset_alert(GkrellmAlert *);
+void		gkrellm_reset_alert(GkrellmAlert *alert);
+void		gkrellm_reset_alert_soft(GkrellmAlert *alert);
 void		gkrellm_reset_panel_alerts(GkrellmPanel *);
 void		gkrellm_freeze_alert(GkrellmAlert *);
 void		gkrellm_thaw_alert(GkrellmAlert *);
@@ -347,6 +352,8 @@ void		gkrellm_alert_set_triggers(GkrellmAlert *alert,
 void		gkrellm_alert_set_delay(GkrellmAlert *alert, gint delay);
 void		gkrellm_alert_delay_config(GkrellmAlert *alert, gint step,
 						gint high, gint low);
+void		gkrellm_alert_commands_config(GkrellmAlert *alert,
+						gboolean alarm, gboolean warn);
 
 
   /* GKrellM Styles and Textstyles
