@@ -89,7 +89,7 @@
 */
 #define	GKRELLM_VERSION_MAJOR	2
 #define	GKRELLM_VERSION_MINOR	1
-#define	GKRELLM_VERSION_REV		8
+#define	GKRELLM_VERSION_REV		10
 #define	GKRELLM_EXTRAVERSION	""
 
 #define GKRELLM_CHECK_VERSION(major,minor,rev)    \
@@ -602,7 +602,9 @@ typedef struct
 	gint		transparency;
 	gboolean	bg_piximage_override;
 
-	gint		y_mapped;
+	gint		y_mapped,
+				auto_recalibrate_delay;
+
 	GtkWidget	*config_window;
 
 	GkrellmSpacer	top_spacer,
@@ -651,7 +653,7 @@ typedef struct
 	gint		y_p,
 				y_pp;
 	gint		y,				/* Each data layer draws at an offset y and */
-				h,				/* within height h of its parent GkrellmChart	*/
+				h,				/* within height h of its parent GkrellmChart*/
 				w;				/* Width of data allocated.				*/
 	gint		maxval;
 	}
@@ -743,7 +745,7 @@ typedef struct
 				suppress_command,
 				check_low,
 				check_high,
-				check_boolean;
+				check_hardwired;
 	gchar		*warn_command,
 				*alarm_command,
 				*voice_string;
@@ -775,6 +777,8 @@ typedef struct
 				*voice_repeat_spin_button,
 				*delay_spin_button,
 				*delete_button;
+	gboolean	do_alarm_command,
+				do_warn_command;
 
 	gfloat		max_high,		/* limit adjustment values */
 				min_low,
