@@ -47,6 +47,8 @@ gkrellm_message_dialog(gchar *title, gchar *message)
 				NULL);
 	g_signal_connect_swapped(GTK_OBJECT(dialog), "response",
 				G_CALLBACK(gtk_widget_destroy), GTK_OBJECT(dialog));
+	gtk_window_set_wmclass(GTK_WINDOW(dialog),
+				"Gkrellm_dialog", "Gkrellm");
 
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 8);
@@ -86,6 +88,8 @@ gkrellm_config_message_dialog(gchar *title, gchar *message)
 				GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 				GTK_STOCK_OK, GTK_RESPONSE_OK,
 				NULL);
+	gtk_window_set_wmclass(GTK_WINDOW(dialog),
+				"Gkrellm_dialog", "Gkrellm");
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 8);
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), vbox,
@@ -857,20 +861,7 @@ N_("The default for most charts is to automatically adjust the number of\n"
 	"fixed grid resolutions in the chart config windows.  However,\n"
 	"some combination of the auto scaling modes may give best results.\n"),
 "\n",
-N_("<ul>Auto number of grids:\n"),
-N_("\tThis means to scale the chart to have as many grids as is necessary\n"
-	"\tto show all the data on the chart without clipping.\n"),
-N_("\tOnce a grid density saturates a chart, grids will not be visible.\n"),
-"\n",
-N_("<ul>Auto grid resolution"),
-N_(" has two meanings:\n"),
-N_("\t1) If using a fixed number of grids, it means to set the\n"
-	"\tresolution per grid to the smallest value in a base to peak range\n"
-	"\tthat draws data without clipping.  The peak is the maximum data\n"
-	"\tvalue encountered and the base is 1/5 the peak.\n"),
-N_("\t2) If using auto number of grids, it means to set the resolution\n"
-	"\tper grid to a value such that drawing the peak value encountered\n"
-	"\trequires at least 5 grids to be drawn.\n"),
+N_("See the README or do a \"man gkrellm\" for more information.\n"),
 "\n",
 N_("<h>Chart Labels\n"),
 N_("Chart label format strings place text on charts using position codes:\n"),
@@ -912,7 +903,7 @@ create_general_tab(GtkWidget *tab_vbox)
 	GtkWidget		*tabs;
 	GtkWidget		*vbox, *vbox1, *vbox2;
 	GtkWidget		*hbox;
-	GtkWidget		*text;
+	GtkWidget		*label, *text;
 	gint			i;
 
 	tabs = gtk_notebook_new();
@@ -942,7 +933,7 @@ create_general_tab(GtkWidget *tab_vbox)
 			_("System name display"));
 
 	gkrellm_gtk_check_button_connected(vbox, &save_position_button,
-			_GK.save_position, FALSE, FALSE, 10,
+			_GK.save_position, FALSE, FALSE, 6,
 			cb_general, NULL,
 		_("Remember screen location at exit and move to it at next startup"));
 
@@ -964,6 +955,16 @@ create_general_tab(GtkWidget *tab_vbox)
 _("Make gkrellm a topmost window (restart gkrellm for this to take effect)."));
 #endif
 
+	if (_GK.client_mode)
+		{
+		hbox = gtk_hbox_new(FALSE, 0);
+		gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 6);
+		gkrellm_gtk_alert_button(hbox, NULL, FALSE, FALSE, 4, TRUE,
+					cb_gkrellmd_disconnect_alert, NULL);
+		label = gtk_label_new(_("gkrellmd server disconnect"));
+		gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, TRUE, 4);
+		}
+
 	vbox = gkrellm_gtk_framed_vbox_end(vbox, NULL, 4, FALSE, 0, 2);
 	gkrellm_gtk_spin_button(vbox, NULL, (gfloat) _GK.update_HZ,
 			2.0, 20.0, 1.0, 1.0, 0, 55,
@@ -1135,6 +1136,8 @@ cb_font_dialog(GtkWidget *widget, AltFontSelect *afs)
 	if (afs->fontseldlg)
 		return;
 	w = gtk_font_selection_dialog_new(_(afs->name));
+	gtk_window_set_wmclass(GTK_WINDOW(w),
+				"Gkrellm_dialog", "Gkrellm");
 	fsd = GTK_FONT_SELECTION_DIALOG(w);
 	afs->fontseldlg = fsd;
 	gtk_font_selection_dialog_set_font_name(fsd, afs->string);
@@ -2008,9 +2011,6 @@ cb_tree_selection_changed(GtkTreeSelection *selection, gpointer data)
 				MONITOR_COLUMN, &selected_monitor,
 				PAGE_COLUMN, &page,
 				-1);
-	if (_GK.debug_level & DEBUG_GUI)
-		printf("tree_selection %p: %s\n", selected_monitor,
-				selected_monitor ? selected_monitor->name : "--");
 	if (selected_monitor && selected_monitor->privat)
 		{
 		page = selected_monitor->privat->config_page;
@@ -2096,7 +2096,7 @@ create_config_window(void)
 	gtk_notebook_set_show_tabs(config_notebook, FALSE);
 
 	model = gtk_tree_store_new(N_COLUMNS,
-				G_TYPE_STRING, G_TYPE_INT, G_TYPE_POINTER);
+				G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_INT);
 	gtk_tree_store_append(model, &iter, NULL);
 	gtk_tree_store_set(model, &iter, NAME_COLUMN, _("General"), -1);
 	vbox = create_config_page(NULL, model, &iter, config_notebook);
