@@ -120,7 +120,10 @@ update_host(void)
 	*/
 	connect_state = gkrellm_client_server_connect_state();
 	if (connect_state == 2)		/* thread is trying a reconnect */
-		gkrellm_check_alert(server_alert, 1.0);		/* Warning	*/
+		{
+		if (_GK.client_server_reconnect_timeout <= 0)
+			gkrellm_check_alert(server_alert, 1.0);		/* Warning	*/
+		}
 	else if (connect_state == 0)	/* Lost connection			*/
 		{
 		gkrellm_check_alert(server_alert, 2.0);		/* Alarm 	*/
@@ -144,6 +147,66 @@ update_host(void)
 		}
 	}
 
+static void
+cb_command_process(GkrellmAlert *alert, gchar *src, gchar *buf, gint size,
+			gpointer data)
+	{
+	gchar	*s, c;
+	gint	len;
+
+	if (!buf || size < 1)
+		return;
+	--size;
+	*buf = '\0';
+	if (!src)
+		return;
+	for (s = src; *s != '\0' && size > 0; ++s)
+		{
+		len = 1;
+		if (*s == '$' && *(s + 1) != '\0')
+			{
+			if ((c = *(s + 1)) == 'H')
+				len = snprintf(buf, size, "%s", gkrellm_sys_get_host_name());
+			++s;
+			}
+		else
+			*buf = *s;
+		size -= len;
+		buf += len;
+		}
+	*buf = '\0';
+	}
+
+static void
+cb_alert_trigger(GkrellmAlert *alert, gpointer data)
+	{
+	alert->panel = host;
+	}
+
+static void
+create_server_alert(void)
+	{
+	if (!server_alert)
+		{
+		/* This is a hardwired alert, so zero config values.
+		|  Use the high alert as a binary alert by setting the high warn
+		|  and alarm limits to 0.5 and 1.5.  A 1.0 check above will
+		|  trigger a warning and a 2.0 check will trigger an alarm.
+		|  A 0.0 check will reset it.
+		*/
+		server_alert = gkrellm_alert_create(host, NULL,
+					_("gkrellmd server disconnect"),
+					TRUE,	/* check high */
+					FALSE, 	/* no check low */
+					TRUE, 0.0, 0.0, 0.0, 0.0, 0);
+		}
+	gkrellm_alert_set_triggers(server_alert, 1.5, 0.5, 0.0, 0.0);
+	gkrellm_alert_commands_config(server_alert, TRUE, FALSE);
+	gkrellm_alert_trigger_connect(server_alert, cb_alert_trigger, NULL);
+	gkrellm_alert_command_process_connect(server_alert,
+				cb_command_process, NULL);
+	}
+
 static void
 create_hostname(GtkWidget *vbox, gint first_create)
 	{
@@ -158,22 +221,7 @@ create_hostname(GtkWidget *vbox, gint first_create)
 		{
 		hostname = _GK.server_hostname;
 		system_name = _GK.server_sysname;
-		if (!server_alert)
-			{
-			/* Won't be a config for this alert, so zero config values.
-			|  Use the high alert as a binary alert by setting the high warn
-			|  and alarm limits to 0.5 and 1.5.  A 1.0 check above will
-			|  trigger a warning and a 2.0 check will trigger an alarm.
-			|  A 0.0 check will reset it.
-			|  No alert callback, so the host panel gets a big default alarm.
-			|  
-			*/
-			server_alert = gkrellm_alert_create(host, NULL, NULL,
-						TRUE,	/* check high */
-						FALSE, 	/* no check low */
-						TRUE, 0.0, 0.0, 0.0, 0.0, 0);
-			gkrellm_alert_set_triggers(server_alert, 1.5, 0.5, 0.0, 0.0);
-			}
+		create_server_alert();
 		}
 	else
 		{
@@ -223,6 +271,11 @@ create_hostname(GtkWidget *vbox, gint first_create)
 		gkrellm_spacers_show(mon_host);
 	}
 
+/* ================================================================== */
+  /* Config is done in gui.c General
+  */
+#define	HOST_CONFIG_KEYWORD		"hostname"
+
 void
 gkrellm_apply_hostname_config(void)
 	{
@@ -243,6 +296,36 @@ gkrellm_apply_hostname_config(void)
 		}
 	}
 
+void
+cb_gkrellmd_disconnect_alert(GtkWidget *button, gpointer data)
+	{
+	gkrellm_alert_config_window(&server_alert);
+	}
+
+static void
+save_host_config(FILE *f)
+	{
+	if (_GK.client_mode && server_alert)
+		gkrellm_save_alertconfig(f, server_alert, HOST_CONFIG_KEYWORD, NULL);
+	}
+
+static void
+load_host_config(gchar *arg)
+	{
+	gchar	config[32], item[CFG_BUFSIZE];
+	gint	n;
+
+	n = sscanf(arg, "%31s %[^\n]", config, item);
+	if (n == 2)
+		{
+		if (!strcmp(config, GKRELLM_ALERTCONFIG_KEYWORD))
+			{
+			if (!server_alert)
+				create_server_alert();
+			gkrellm_load_alertconfig(&server_alert, item);
+			}
+		}
+	}
 
 static GkrellmMonitor	monitor_host =
 	{
@@ -253,9 +336,9 @@ static GkrellmMonitor	monitor_host =
 	NULL,		/* The config tab create function	*/
 	NULL,		/* Instant apply */
 
-	NULL,		/* Save user conifg			*/
-	NULL,		/* Load user config			*/
-	NULL,		/* config keyword			*/
+	save_host_config,	/* Save user conifg			*/
+	load_host_config,	/* Load user config			*/
+	HOST_CONFIG_KEYWORD, /* config keyword			*/
 
 	NULL,				/* Undef 2	*/
 	NULL,				/* Undef 1	*/
