@@ -236,9 +236,11 @@ gkrellm_inet_client_divert(void (*read_tcp_func)())
 static void
 format_chart_text(InetMon *in, gchar *src_string, gchar *buf, gint size)
 	{
+	GList			*list;
 	GkrellmChart	*cp;
+	GkrellmChartdata *cd;
 	gchar			c, *s, *s1;
-	gint			len, value;
+	gint			len, value, n, i, w;
 
 	if (!buf || size < 1)
 		return;
@@ -247,6 +249,7 @@ format_chart_text(InetMon *in, gchar *src_string, gchar *buf, gint size)
 	if (!src_string)
 		return;
 	cp = in->chart;
+	w = gkrellm_chart_width();
 	for (s = text_format_locale; *s != '\0' && size > 0; ++s)
 		{
 		len = 1;
@@ -260,10 +263,40 @@ format_chart_text(InetMon *in, gchar *src_string, gchar *buf, gint size)
 				value = in->active0;
 			else if (c == 'l' && *in->label0)
 				s1 = in->label0;
+			else if (c == 'c' && *(s + 2))
+				{
+				i = 0;
+				sscanf(s + 2, "%d%n", &n, &i);
+				s += i;
+				--n;
+				if (n > w)
+					n = w;
+				list = in->chart_minute->cd_list;
+				cd = (GkrellmChartdata *) list->data;
+				if (*in->label0)
+					for (value = in->hits0_minute; n > 0; --n)
+						value += gkrellm_get_chartdata_data(cd, w - n);
+				}
 			else if (c == 'A' && *in->label1)
 				value = in->active1;
 			else if (c == 'L' && *in->label1)
 				s1 = in->label1;
+			else if (c == 'C' && *(s + 2))
+				{
+				i = 0;
+				sscanf(s + 2, "%d%n", &n, &i);
+				s += i;
+				--n;
+				if (n > w)
+					n = w;
+				list = in->chart_minute->cd_list;
+				if (list->next)
+					list = list->next;
+				cd = (GkrellmChartdata *) list->data;
+				if (*in->label1)
+					for (value = in->hits1_minute; n > 0; --n)
+						value += gkrellm_get_chartdata_data(cd, w - n);
+				}
 			if (value >= 0)
 				len = snprintf(buf, size, "%d", value);
 			else
@@ -1740,8 +1773,10 @@ N_("<h>Chart Labels\n"),
 N_("Substitution variables for the format string for chart labels:\n"),
 N_("\t$M    maximum chart value\n"),
 N_("\t$a    current active connections for Data0\n"),
+N_("\t$cN   total connections in last N minutes for Data0\n"),
 N_("\t$l    label for Data0\n"),
 N_("\t$A    current active connections for Data1\n"),
+N_("\t$CN   total connections in last N minutes for Data1\n"),
 N_("\t$L    label for Data1\n"),
 
 "\n",
