@@ -1499,25 +1499,21 @@ cb_size_allocate(GtkWidget *w, GtkAllocation *size, gpointer data)
 static gboolean
 cb_map_event(GtkWidget *widget, GdkEvent *event, gpointer data)
 	{
-	/* Various window managers have bugs where the _NET_WM_STATE property set
-	|  prior to window mapping is not recognized.  As a temporary hack, users
-	|  can edit ~/.gkrellm2/user_config and set the set_wm_state_hack to 1 so
-	|  after mapping send extra _NET_WM_STATE changed messages in an attempt
-	|  to get these window managers to work.
+	/* Some window managers don't recognize when _NET_WM_STATE property is set
+	|  prior to window mapping.  As a temporary hack send extra _NET_WM_STATE
+	|  changed messages in an attempt to get these window managers to work.
 	*/
-	if (_GK.set_wm_state_hack)	/* Temporary option */
-		{
-		if (_GK.sticky_state)
-			gtk_window_stick(GTK_WINDOW(top_window));
-		if (_GK.state_skip_pager)
-			gkrellm_winop_state_skip_pager(TRUE);
-		if (_GK.state_skip_taskbar)
-			gkrellm_winop_state_skip_taskbar(TRUE);
-		if (_GK.state_above)
-			gkrellm_winop_state_above(TRUE);
-		else if (_GK.state_above)
-			gkrellm_winop_state_below(TRUE);
-		}
+	if (_GK.sticky_state)
+		gtk_window_stick(GTK_WINDOW(top_window));
+	if (_GK.state_skip_pager)
+		gkrellm_winop_state_skip_pager(TRUE);
+	if (_GK.state_skip_taskbar)
+		gkrellm_winop_state_skip_taskbar(TRUE);
+	if (_GK.state_above)
+		gkrellm_winop_state_above(TRUE);
+	else if (_GK.state_below)
+		gkrellm_winop_state_below(TRUE);
+
 	return FALSE;
 	}
 
@@ -1585,6 +1581,7 @@ cb_configure_notify(GtkWidget *widget, GdkEventConfigure *ev, gpointer data)
 void
 gkrellm_save_all()
 	{
+	save_net_data();
 	save_inet_data();
 	if (_GK.save_position)
 		set_or_save_position(1);
@@ -1949,8 +1946,10 @@ main(gint argc, gchar **argv)
 			if (s[5] != '\0')
 				_GK.debug = atoi(s + 5);
 			else
-				++_GK.debug;
+				_GK.debug = 1;
 			}
+		else if (!strcmp(s, "nolock"))
+			_GK.nolock = TRUE;
 		else if (!strcmp(s, "demo"))
 			++_GK.demo;
 		else if (!strcmp(s, "test"))
@@ -1986,7 +1985,7 @@ main(gint argc, gchar **argv)
 	load_user_config(FALSE);		
 	decorated = (_GK.command_line_decorated || _GK.decorated);
 	if (   _GK.command_line_plugin || _GK.command_line_theme
-		|| _GK.debug_level > 0 || _GK.debug > 0
+		|| _GK.debug_level > 0 || _GK.debug > 0 || _GK.nolock
 	   )
 		_GK.allow_multiple_instances_real = TRUE;
 	_GK.allow_multiple_instances_real |= _GK.allow_multiple_instances;
