@@ -76,8 +76,13 @@ typedef struct
 						rx_totalB,
 						tx_totalA,
 						tx_totalB;
+	gdouble				rx_day, rx_week, rx_month;
+	gdouble				tx_day, tx_week, tx_month;
+	gint				time_day, time_week, time_month;
 	gboolean			show_totalB,
 						totals_shown,
+						reset_button_in,
+						stats_button_in,
 						mouse_in_chart;
 	GkrellmLauncher		launch;
 	GtkWidget			*launch_entry,
@@ -106,6 +111,7 @@ static GList	*net_mon_list;
 static GList	*net_mon_sys_list;
 static GList	*timer_defaults_list;
 static gchar	*lock_directory;
+static gchar	*net_data_dir;
 
 static void		(*read_net_data)();
 static void		(*check_net_routes)();
@@ -114,7 +120,7 @@ static gboolean	(*isdn_is_online)();
 static gboolean	net_use_routed;
 static gboolean	net_config_use_routed;
 
-
+static gint		reset_mday;
 
 static gint
 strcmp_net_name(NetMon *net1, NetMon *net2)
@@ -167,6 +173,8 @@ lookup_net(gchar *name)
 	NetMon	*net;
 	GList	*list;
 
+	if (!name)
+		return NULL;
 	for (list = net_mon_list; list; list = list->next)
 		{
 		net = (NetMon *) list->data;
@@ -298,6 +306,7 @@ gkrellm_net_set_lock_directory(gchar *dir)
 	lock_directory = g_strdup(dir);
 	}
 
+
 /* ======================================================================== */
 /* Exporting net data for plugins */
 
@@ -404,6 +413,7 @@ static GkrellmDecal	*time_decal,
 static GkrellmDecal	*decal_totalA,
 					*decal_totalB,
 					*decal_reset;
+static GkrellmDecal	*decal_stats;
 
 static gchar		*timer_on_command;
 static gchar		*timer_off_command;
@@ -430,6 +440,23 @@ static time_t		net_timer0;
 static gint			net_style_id,
 					timer_style_id;
 
+static GkrellmSizeAbbrev    stats_bytes_abbrev[]    =
+	{
+	{ KB_SIZE(1),       1,              "%.0f" },
+	{ KB_SIZE(10),      KB_SIZE(1),     "%.1fKB" },
+	{ MB_SIZE(1),       KB_SIZE(1),     "%.2fKB" },
+	{ MB_SIZE(10),      MB_SIZE(1),     "%.3fMB" },
+	{ MB_SIZE(100),     MB_SIZE(1),     "%.2fMB" },
+	{ GB_SIZE(1),       MB_SIZE(1),     "%.2fMB" },
+	{ GB_SIZE(10),      GB_SIZE(1),     "%.3fGB" },
+	{ GB_SIZE(100),     GB_SIZE(1),     "%.2fGB" },
+	{ TB_SIZE(1),       GB_SIZE(1),     "%.2fGB" },
+	{ TB_SIZE(10),      TB_SIZE(1),     "%.3fTB" },
+	{ TB_SIZE(100),     TB_SIZE(1),     "%.3fTB" },
+	{ TB_SIZE(1000),    TB_SIZE(1),     "%.2fTB" }
+	};
+
+
 
 static void
 draw_led(NetMon *net, int rxtx, int led_index)
@@ -493,6 +520,113 @@ draw_timer(GkrellmPanel *p, gint seconds, gint force)
 	gkrellm_draw_panel_layers(timer_panel);
 	}
 
+static void
+add_net_stat(GtkWidget *table, gdouble v, gint c0, gint c1, gint r0, gint r1)
+	{
+	GtkWidget	*label;
+	gchar		buf[64];
+
+	format_size_abbrev(buf, sizeof(buf), (gfloat) v,
+				&stats_bytes_abbrev[0],
+				sizeof(stats_bytes_abbrev) / sizeof(GkrellmSizeAbbrev));
+	label = gtk_label_new(buf);
+	gtk_table_attach_defaults(GTK_TABLE(table), label, c0, c1, r0, r1);
+	}
+
+static void
+add_net_time(GtkWidget *table, time_t t, gint c0, gint c1, gint r0, gint r1)
+	{
+	GtkWidget	*label;
+	gchar		buf[64];
+	gint		hours, minutes;
+
+	minutes = t / 60;
+	hours = minutes / 60;
+	minutes %= 60;
+
+	snprintf(buf, sizeof(buf), "%4d:%02d", hours, minutes);
+	label = gtk_label_new(buf);
+	gtk_table_attach_defaults(GTK_TABLE(table), label, c0, c1, r0, r1);
+	}
+
+static void
+net_stats_dialog(NetMon *net)
+	{
+	GtkWidget	*top_win;
+	GtkWidget	*dialog;
+	GtkWidget	*table;
+	GtkWidget	*vbox, *label, *sep;
+	gchar		buf[64];
+
+	top_win = gkrellm_get_top_window();
+	snprintf(buf, sizeof(buf), "%s", net->name);
+	dialog = gtk_dialog_new_with_buttons(buf,
+				GTK_WINDOW(top_win),
+				GTK_DIALOG_DESTROY_WITH_PARENT,
+				GTK_STOCK_OK, GTK_RESPONSE_NONE,
+				NULL);
+	gtk_window_set_wmclass(GTK_WINDOW(dialog),
+				"Gkrellm_dialog", "Gkrellm");
+	g_signal_connect_swapped(GTK_OBJECT(dialog), "response",
+				G_CALLBACK(gtk_widget_destroy), GTK_OBJECT(dialog));
+
+	vbox = gtk_vbox_new(FALSE, 0);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox), 12);
+	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), vbox,
+				FALSE, FALSE, 0);
+
+	table = gtk_table_new(5, 7, FALSE /*homogeneous*/);
+	gtk_table_set_col_spacings(GTK_TABLE(table), 12);
+	gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 0);
+
+	label = gtk_label_new(_("Receive"));
+	gtk_table_attach_defaults(GTK_TABLE(table), label, 2, 3, 0, 1);
+	label = gtk_label_new(_("Transmit"));
+	gtk_table_attach_defaults(GTK_TABLE(table), label, 3, 4, 0, 1);
+	label = gtk_label_new(_("Total"));
+	gtk_table_attach_defaults(GTK_TABLE(table), label, 4, 5, 0, 1);
+	if (net == net_timed)
+		{
+		label = gtk_label_new(_("Connect Time"));
+		gtk_table_attach_defaults(GTK_TABLE(table), label, 6, 7, 0, 1);
+		sep = gtk_vseparator_new();
+		gtk_table_attach_defaults(GTK_TABLE(table), sep, 5, 6, 0, 5);
+		}
+
+	label = gtk_label_new(_("Today"));
+	gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 2, 3);
+	label = gtk_label_new(_("Week"));
+	gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 3, 4);
+	label = gtk_label_new(_("Month"));
+	gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 4, 5);
+
+	sep = gtk_vseparator_new();
+	gtk_table_attach_defaults(GTK_TABLE(table), sep, 1, 2, 0, 5);
+	sep = gtk_hseparator_new();
+	gtk_table_attach_defaults(GTK_TABLE(table), sep,
+			0, net == net_timed ? 7 : 6, 1, 2);
+
+	add_net_stat(table, net->rx_day,   2, 3, 2, 3);
+	add_net_stat(table, net->rx_week,  2, 3, 3, 4);
+	add_net_stat(table, net->rx_month, 2, 3, 4, 5);
+
+	add_net_stat(table, net->tx_day,   3, 4, 2, 3);
+	add_net_stat(table, net->tx_week,  3, 4, 3, 4);
+	add_net_stat(table, net->tx_month, 3, 4, 4, 5);
+
+	add_net_stat(table, net->rx_day   + net->tx_day,  4, 5, 2, 3);
+	add_net_stat(table, net->rx_week  + net->tx_week, 4, 5, 3, 4);
+	add_net_stat(table, net->rx_month + net->tx_month, 4, 5, 4, 5);
+
+	if (net == net_timed)
+		{
+		add_net_time(table, net->time_day, 6, 7, 2, 3);
+		add_net_time(table, net->time_week, 6, 7, 3, 4);
+		add_net_time(table, net->time_month, 6, 7, 4, 5);
+		}
+	gtk_widget_show_all(dialog);
+	}
+
 
 static gint
 get_connect_state(void)
@@ -627,6 +761,12 @@ update_timer_button_monitor(void)
 				draw_timer(timer_panel, (int) (time(0) - net_timer0), 0);
 			break;
 		}
+	if (net_timed && net_timed->up)
+		{
+		net_timed->time_day += 1;
+		net_timed->time_week += 1;
+		net_timed->time_month += 1;
+		}
 	}
 
 static void
@@ -897,9 +1037,10 @@ static void
 format_net_data(NetMon *net, gchar *src_string, gchar *buf, gint size)
 	{
 	GkrellmChart	*cp;
-	gchar	c, *s, *s1;
-	gint	len, bytes;
-	gdouble	fbytes;
+	gchar			c, *s, *s1;
+	gint			len, bytes;
+	gdouble			fbytes;
+	gboolean		month, day, week;
 
 	if (!buf || size < 1)
 		return;
@@ -912,10 +1053,18 @@ format_net_data(NetMon *net, gchar *src_string, gchar *buf, gint size)
 	for (s = src_string; *s != '\0' && size > 0; ++s)
 		{
 		len = 1;
+		month = week = day = FALSE;
 		if (*s == '$' && *(s + 1) != '\0')
 			{
 			bytes = -1;
 			fbytes = -1.0;
+			if ((c = *(s + 2)) == 'm')	/* cumulative modifiers */
+				month = TRUE;
+			else if (c == 'w')
+				week = TRUE;
+			else if (c == 'd')
+				day = TRUE;
+
 			if ((c = *(s + 1)) == 'T')
 				bytes = net->rx_current + net->tx_current;
 			else if (c == 'M')
@@ -925,12 +1074,42 @@ format_net_data(NetMon *net, gchar *src_string, gchar *buf, gint size)
 			else if (c == 'r')
 				bytes = net->rx_current;
 			else if (c == 'o')
-				fbytes = net->show_totalB ? net->tx_totalB : net->tx_totalA;
+				{
+				if (month)
+					fbytes = net->tx_month;
+				else if (week)
+					fbytes = net->tx_week;
+				else if (day)
+					fbytes = net->tx_day;
+				else
+					fbytes = net->show_totalB
+								? net->tx_totalB : net->tx_totalA;
+				}
 			else if (c == 'i')
-				fbytes = net->show_totalB ? net->rx_totalB : net->rx_totalA;
+				{
+				if (month)
+					fbytes = net->rx_month;
+				else if (week)
+					fbytes = net->rx_week;
+				else if (day)
+					fbytes = net->rx_day;
+				else
+					fbytes = net->show_totalB
+								? net->rx_totalB : net->rx_totalA;
+				}
 			else if (c == 'O')
-				fbytes = net->show_totalB ? (net->rx_totalB + net->tx_totalB)
+				{
+				if (month)
+					fbytes = net->rx_month + net->tx_month;
+				else if (week)
+					fbytes = net->rx_week + net->tx_week;
+				else if (day)
+					fbytes = net->rx_day + net->tx_day;
+				else
+					fbytes = net->show_totalB
+							? (net->rx_totalB + net->tx_totalB)
 							: (net->rx_totalA + net->tx_totalA);
+				}
 			else if (c == 'L')
 				{
 				if (!*(net->label))
@@ -961,9 +1140,12 @@ format_net_data(NetMon *net, gchar *src_string, gchar *buf, gint size)
 				len = format_size_abbrev(buf, size, (gfloat) fbytes,
 					&total_bytes_abbrev[0],
 					sizeof(total_bytes_abbrev) /sizeof(GkrellmSizeAbbrev));
-				net->totals_shown = TRUE;
+				if (!day && !week && !month)
+					net->totals_shown = TRUE;
 				}
 			++s;
+			if (day || week || month)
+				++s;
 			}
 		else
 			*buf = *s;
@@ -992,31 +1174,40 @@ cb_command_process(GkrellmAlert *alert, gchar *src, gchar *dst, gint len,
 	format_net_data(net, src, dst, len);
 	}
 
-static gboolean
-draw_totals_buttons(NetMon *net)
+static void
+draw_chart_buttons(NetMon *net)
 	{
 	gint	frame, x, y;
 
-	if (   !net->totals_shown || !net->chart_labels
-		|| !decal_totalA || !decal_totalB || !decal_reset
+	if (   net->totals_shown && net->chart_labels
+		&& decal_totalA && decal_totalB && decal_reset
 	   )
-		return FALSE;
-	x = gkrellm_chart_width() - 2 * decal_totalA->w;
-	y = 2;
+		{
+		x = gkrellm_chart_width() - 2 * decal_totalA->w;
+		y = 2;
 
-	frame = net->show_totalB ? D_MISC_BUTTON_OUT : D_MISC_BUTTON_IN;
-	gkrellm_draw_decal_pixmap(NULL, decal_totalA, frame);
-	gkrellm_draw_decal_on_chart(net->chart, decal_totalA, x, y);
+		frame = net->show_totalB ? D_MISC_BUTTON_OUT : D_MISC_BUTTON_IN;
+		gkrellm_draw_decal_pixmap(NULL, decal_totalA, frame);
+		gkrellm_draw_decal_on_chart(net->chart, decal_totalA, x, y);
 
-	frame = net->show_totalB ? D_MISC_BUTTON_IN : D_MISC_BUTTON_OUT;
-	gkrellm_draw_decal_pixmap(NULL, decal_totalB, frame);
-	gkrellm_draw_decal_on_chart(net->chart, decal_totalB,
-				x + decal_totalA->w, y);
+		frame = net->show_totalB ? D_MISC_BUTTON_IN : D_MISC_BUTTON_OUT;
+		gkrellm_draw_decal_pixmap(NULL, decal_totalB, frame);
+		gkrellm_draw_decal_on_chart(net->chart, decal_totalB,
+					x + decal_totalA->w, y);
 
-	gkrellm_draw_decal_pixmap(NULL, decal_reset, D_MISC_BUTTON_OUT);
-	gkrellm_draw_decal_on_chart(net->chart, decal_reset,
-				x + decal_totalA->w, y + decal_totalA->h + 4);
-	return TRUE;
+		frame = net->reset_button_in ? D_MISC_BUTTON_IN : D_MISC_BUTTON_OUT;
+		gkrellm_draw_decal_pixmap(NULL, decal_reset, frame);
+		gkrellm_draw_decal_on_chart(net->chart, decal_reset,
+					x + decal_totalA->w, y + decal_totalA->h + 4);
+		}
+	if (decal_stats)
+		{
+		x = gkrellm_chart_width() - decal_stats->w;
+		y = net->chart->h - decal_stats->h;
+		frame = net->stats_button_in ? D_MISC_BUTTON_IN : D_MISC_BUTTON_OUT;
+		gkrellm_draw_decal_pixmap(NULL, decal_stats, frame);
+		gkrellm_draw_decal_on_chart(net->chart, decal_stats, x, y);
+		}
 	}
 
 static void
@@ -1027,7 +1218,7 @@ refresh_net_chart(NetMon *net)
 	gkrellm_draw_chartdata(net->chart);
 	draw_net_chart_labels(net);
 	if (net->mouse_in_chart)
-		draw_totals_buttons(net);
+		draw_chart_buttons(net);
 	gkrellm_draw_chart_to_screen(net->chart);
 	}
 
@@ -1050,10 +1241,12 @@ cb_chart_press(GtkWidget *widget, GdkEventButton *ev, NetMon *net)
 		}
 	else if (check_button && gkrellm_in_decal(decal_reset, ev))
 		{
-		if (net->show_totalB)
-			net->rx_totalB = net->tx_totalB = 0;
-		else
-			net->rx_totalA = net->tx_totalA = 0;
+		net->reset_button_in = TRUE;
+		refresh_net_chart(net);
+		}
+	else if (gkrellm_in_decal(decal_stats, ev))
+		{
+		net->stats_button_in = TRUE;
 		refresh_net_chart(net);
 		}
 	else if (ev->button == 1 && ev->type == GDK_BUTTON_PRESS)
@@ -1070,12 +1263,32 @@ cb_chart_press(GtkWidget *widget, GdkEventButton *ev, NetMon *net)
 	return FALSE;
 	}
 
+static gint
+cb_chart_release(GtkWidget *widget, GdkEventButton *ev, NetMon *net)
+	{
+	if (!net->reset_button_in && !net->stats_button_in)
+		return FALSE;
+	if (net->stats_button_in && gkrellm_in_decal(decal_stats, ev))
+		net_stats_dialog(net);
+	if (net->reset_button_in && gkrellm_in_decal(decal_reset, ev))
+		{
+		if (net->show_totalB)
+			net->rx_totalB = net->tx_totalB = 0;
+		else
+			net->rx_totalA = net->tx_totalA = 0;
+		}
+	net->reset_button_in = FALSE;
+	net->stats_button_in = FALSE;
+	refresh_net_chart(net);
+	return FALSE;
+	}
+
 static gint
 cb_chart_enter(GtkWidget *w, GdkEventButton *ev, NetMon *net)
 	{
 	net->mouse_in_chart = TRUE;
-	if (draw_totals_buttons(net))
-		gkrellm_draw_chart_to_screen(net->chart);
+	draw_chart_buttons(net);
+	gkrellm_draw_chart_to_screen(net->chart);
 	return FALSE;
 	}
 
@@ -1083,8 +1296,9 @@ static gint
 cb_chart_leave(GtkWidget *w, GdkEventButton *ev, NetMon *net)
 	{
 	net->mouse_in_chart = FALSE;
-	if (net->totals_shown)
-		refresh_net_chart(net);
+	net->reset_button_in = FALSE;
+	net->stats_button_in = FALSE;
+	refresh_net_chart(net);
 	return FALSE;
 	}
 
@@ -1150,7 +1364,7 @@ create_net_monitor(GtkWidget *vbox, NetMon *net, gint first_create)
     gkrellm_chartconfig_grid_resolution_connect(cp->config,
                 setup_net_scaling, net);
     gkrellm_chartconfig_grid_resolution_adjustment(cp->config, TRUE,
-                0, (gfloat) MIN_GRID_RES, (gfloat) MAX_GRID_RES, 0, 0, 0, 85);
+                0, (gfloat) MIN_GRID_RES, (gfloat) MAX_GRID_RES, 0, 0, 0, 0);
 
     gkrellm_chartconfig_grid_resolution_label(cp->config,
                 _("rx/tx bytes per sec"));
@@ -1185,6 +1399,8 @@ create_net_monitor(GtkWidget *vbox, NetMon *net, gint first_create)
 					G_CALLBACK(net_expose_event), NULL);
 		g_signal_connect(G_OBJECT(cp->drawing_area), "button_press_event",
 					G_CALLBACK(cb_chart_press), net);
+		g_signal_connect(G_OBJECT(cp->drawing_area), "button_release_event",
+					G_CALLBACK(cb_chart_release), net);
 		g_signal_connect(G_OBJECT(cp->drawing_area), "enter_notify_event",
 					G_CALLBACK(cb_chart_enter), net);
 		g_signal_connect(G_OBJECT(cp->drawing_area), "leave_notify_event",
@@ -1224,6 +1440,150 @@ net_timer_visibility(void)
 		}
 	}
 
+
+#define	NET_DATA_VERSION	1
+
+static gchar	days_in_month[12] =
+		{ 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31  };
+
+
+static gboolean
+net_accounting_month_new(struct tm *tm)
+	{
+	if (   tm->tm_mday == reset_mday
+		|| (   reset_mday > days_in_month[tm->tm_mon]
+			&& tm->tm_mday == 1
+		   )
+	   )
+		return TRUE;
+	return FALSE;
+	}
+
+void
+save_net_data(void)
+	{
+	FILE		*f;
+	GList		*list;
+	struct tm	*tm  = gkrellm_get_current_time();
+	NetMon		*net;
+	gchar		fname[256];
+
+	for (list = net_mon_list; list; list = list->next)
+		{
+		net = (NetMon *) list->data;
+		if (!net->enabled)
+			continue;
+		snprintf(fname, sizeof(fname), "%s%c%s", net_data_dir,
+					G_DIR_SEPARATOR, net->name);
+		if ((f = fopen(fname, "w")) == NULL)
+			continue;
+		fprintf(f, "%d\n", NET_DATA_VERSION);
+		fputs("wday mday month yday year\n", f);
+		fprintf(f, "%d %d %d %d %d\n", tm->tm_wday,
+					tm->tm_mday, tm->tm_mon, tm->tm_yday, tm->tm_year);
+
+		fputs("day\n", f);
+		fprintf(f, "%.0lf %.0lf\n", net->rx_day, net->tx_day);
+		fputs("week\n", f);
+		fprintf(f, "%.0lf %.0lf\n", net->rx_week, net->tx_week);
+		fputs("month\n", f);
+		fprintf(f, "%.0lf %.0lf\n", net->rx_month, net->tx_month);
+		if (net == net_timed)
+			{
+			fputs("connect time: day week month\n", f);
+			fprintf(f, "%d %d %d\n",
+						net->time_day, net->time_week, net->time_month);
+			}
+		fclose(f);
+		}
+	}
+
+static void
+load_net_data(void)
+	{
+	FILE		*f;
+	GList		*list;
+	struct tm	*tm  = gkrellm_get_current_time();
+	NetMon		*net;
+	gchar		buf[128], fname[256];
+	gint		wday, mday, month, yday, year, version;
+	gint		day_delta, month_delta;
+
+	for (list = net_mon_list; list; list = list->next)
+		{
+		net = (NetMon *) list->data;
+		snprintf(fname, sizeof(fname), "%s%c%s", net_data_dir,
+					G_DIR_SEPARATOR, net->name);
+		if ((f = fopen(fname, "r")) == NULL)
+			continue;
+		fgets(buf, sizeof(buf), f);
+		if (   sscanf(buf, "%d\n", &version) != 1
+			|| version != NET_DATA_VERSION
+		   )
+			{
+			fclose(f);
+			continue;
+			}
+		fgets(buf, sizeof(buf), f);		/* Comment line */
+		fgets(buf, sizeof(buf), f);
+		sscanf(buf, "%d %d %d %d %d", &wday, &mday, &month, &yday, &year);
+
+		fgets(buf, sizeof(buf), f);		/* day */
+		fgets(buf, sizeof(buf), f);
+		sscanf(buf, "%lf %lf", &net->rx_day, &net->tx_day);
+		fgets(buf, sizeof(buf), f);		/* week */
+		fgets(buf, sizeof(buf), f);
+		sscanf(buf, "%lf %lf", &net->rx_week, &net->tx_week);
+		fgets(buf, sizeof(buf), f);		/* month */
+		fgets(buf, sizeof(buf), f);
+		sscanf(buf, "%lf %lf", &net->rx_month, &net->tx_month);
+		if (   net == net_timed
+			&& fgets(buf, sizeof(buf), f)	/* connect day*/
+		   )
+			{
+			fgets(buf, sizeof(buf), f);
+			sscanf(buf, "%d %d %d",
+						&net->time_day, &net->time_week, &net->time_month);
+			}
+		fclose(f);
+
+		month_delta = (tm->tm_year * 12 + tm->tm_mon) - (year * 12 + month);
+		if (month_delta == 0)
+			day_delta = tm->tm_mday - mday;
+		else if (month_delta == 1)
+			day_delta = days_in_month[month] - mday + tm->tm_mday;
+		else
+			day_delta = 7;		/* max compared to is 6 */
+
+		if (day_delta > 0)
+			{
+			net->rx_day = net->tx_day = 0.0;
+			net->time_day = 0;
+			}
+		if (wday + day_delta != tm->tm_wday)
+			{
+			net->rx_week = net->tx_week = 0.0;
+			net->time_week = 0;
+			}
+		if (   (   tm->tm_mday < reset_mday
+				&& (   (month_delta > 1)
+					|| (month_delta == 1 && mday < reset_mday)
+				   )
+			   )
+			|| (   tm->tm_mday >= reset_mday
+				&& (   (month_delta > 0)
+					|| (month_delta == 0 && mday < reset_mday)
+				   )
+			   )
+		   )
+			{
+			net->rx_month = net->tx_month = 0.0;
+			net->time_month = 0;
+			}
+		}
+	}
+
+
 #define SEC_PAD	0
 
 static void
@@ -1332,8 +1692,10 @@ update_net(void)
 	{
 	GList			*list;
 	NetMon			*net;
+	struct tm		*tm;
 	GkrellmPanel	*p;
 	gint			bytes;
+	gdouble			rxd, txd;
 
 	/* If sysdep code is not reporting route up/down events, then
 	|  gkrellm_net_assign_data() sets a net as up if data is assigned for it.
@@ -1393,10 +1755,36 @@ update_net(void)
 			gkrellm_store_chartdata(net->chart, 0, net->tx, net->rx);
 			net->rx_current = gkrellm_get_current_chartdata(net->rx_cd);
 			net->tx_current = gkrellm_get_current_chartdata(net->tx_cd);
-			net->rx_totalA += (gdouble) net->rx_current;
-			net->tx_totalA += (gdouble) net->tx_current;
-			net->rx_totalB += (gdouble) net->rx_current;
-			net->tx_totalB += (gdouble) net->tx_current;
+			rxd = (gdouble) net->rx_current;
+			txd = (gdouble) net->tx_current;
+			net->rx_totalA += rxd;
+			net->tx_totalA += txd;
+			net->rx_totalB += rxd;
+			net->tx_totalB += txd;
+
+			if (GK.day_tick)
+				{
+				tm = gkrellm_get_current_time();
+				net->rx_day = net->tx_day = 0.0;
+				net->time_day = 0;
+				if (tm->tm_wday == 0)
+					{
+					net->rx_week = net->tx_week = 0.0;
+					net->time_week = 0;
+					}
+				if (net_accounting_month_new(tm))
+					{
+					net->rx_month = net->tx_month = 0.0;
+					net->time_month = 0;
+					}
+				}
+			net->rx_day   += rxd;
+			net->rx_week  += rxd;
+			net->rx_month += rxd;
+			net->tx_day   += txd;
+			net->tx_week  += txd;
+			net->tx_month += txd;
+
 			if (net->alert)
 				{
 				bytes = 0;
@@ -1591,6 +1979,7 @@ create_net(GtkWidget *vbox, gint first_create)
 			if ((net->up || net->force_up) && net->enabled)
 				create_net_monitor(dynamic_net_vbox, net, first_create);
 			}
+		load_net_data();
 		}
 	else
 		{
@@ -1602,7 +1991,8 @@ create_net(GtkWidget *vbox, gint first_create)
 		gkrellm_destroy_decal(decal_totalA);
 		gkrellm_destroy_decal(decal_totalB);
 		gkrellm_destroy_decal(decal_reset);
-		decal_totalA = decal_totalB = decal_reset = NULL;
+		gkrellm_destroy_decal(decal_stats);
+		decal_totalA = decal_totalB = decal_reset = decal_stats = NULL;
 		for (list = net_mon_list; list; list = list->next)
 			{
 			net = (NetMon *) list->data;
@@ -1620,6 +2010,11 @@ create_net(GtkWidget *vbox, gint first_create)
 	decal_reset = gkrellm_create_decal_pixmap(NULL,
 			gkrellm_decal_misc_pixmap(), gkrellm_decal_misc_mask(),
 			N_MISC_DECALS, NULL, 0, 0);
+
+	decal_stats = gkrellm_create_decal_pixmap(NULL,
+			gkrellm_decal_misc_pixmap(), gkrellm_decal_misc_mask(),
+			N_MISC_DECALS, NULL, 0, 0);
+
 	net_spacer_visibility();
 	}
 
@@ -1709,6 +2104,7 @@ save_net_config(FILE *f)
 	fprintf(f, "%s timer_on %s\n", NET_CONFIG_KEYWORD, timer_on_command);
 	fprintf(f, "%s timer_off %s\n", NET_CONFIG_KEYWORD, timer_off_command);
 	fprintf(f, "%s text_format %s\n", NET_CONFIG_KEYWORD, text_format);
+	fprintf(f, "%s reset_mday %d\n", NET_CONFIG_KEYWORD, reset_mday);
 	}
 
 static void
@@ -1728,6 +2124,8 @@ load_net_config(gchar *arg)
 		sscanf(item, "%d", &timer_button_enabled);
 	else if (!strcmp(config, "timer_seconds"))
 		sscanf(item, "%d", &timer_seconds);
+	else if (!strcmp(config, "reset_mday"))
+		sscanf(item, "%d", &reset_mday);
 	else if (!strcmp(config, "timer_iface") && !_GK.client_mode)
 		{
 		if (_GK.demo && !strcmp(item, "none"))
@@ -2049,7 +2447,11 @@ cb_poff_entry(GtkWidget *widget, gpointer data)
 	gkrellm_dup_string(&timer_off_command, s);
 	}
 
-
+static void
+cb_reset_mday(GtkWidget *widget, GtkSpinButton *spin)
+	{
+	reset_mday = gtk_spin_button_get_value_as_int(spin);
+	}
 
 #if !defined(WIN32)
 static gchar	*net_info_text0[] =
@@ -2101,6 +2503,10 @@ N_("\t$o    cumulative transmit bytes\n"),
 N_("\t$L    the optional chart label\n"),
 N_("\t$I    the net interface name\n"),
 "\n",
+N_("The cumulative variables may have a 'd', 'w', or 'm' qualifier for\n"
+   "daily, weekly, or monthly totals.  For example:  $Ow for a\n"
+   "cumulative weekly receive + transmit bytes.\n"),
+"\n",
 N_("Substitution variables may be used in alert commands.\n")
 };
 
@@ -2266,6 +2672,11 @@ create_net_tab(GtkWidget *tab_vbox)
 	g_signal_connect(G_OBJECT(GTK_COMBO(text_format_combo)->entry), "changed",
 			G_CALLBACK(cb_text_format), NULL);
 
+	gkrellm_gtk_spin_button(vbox, NULL, (gfloat) reset_mday,
+			1.0, 31.0, 1.0, 1.0, 0, 55,
+			cb_reset_mday, NULL, FALSE,
+			_("Start day for cumulative monthly transmit and receive bytes"));
+
 /* --Info tab */
 	vbox = gkrellm_gtk_framed_notebook_page(tabs, _("Info"));
 	text = gkrellm_gtk_scrolled_text_view(vbox, NULL,
@@ -2368,6 +2779,8 @@ init_timer_monitor(void)
     monitor_timer.name = _(monitor_timer.name);
 	timer_style_id = gkrellm_add_meter_style(&monitor_timer, TIMER_STYLE_NAME);
 	mon_timer = &monitor_timer;
+	net_data_dir = gkrellm_make_data_file_name("net", NULL);
+	reset_mday = 1;
 	return &monitor_timer;
 	}
 
