@@ -639,3 +639,16 @@ gkrellm_piximage_new_from_file(gchar *fname)
 	return piximage;
 	}
 
+GkrellmPiximage *
+gkrellm_piximage_new_from_inline(const guint8 *data, gboolean copy_pixels)
+	{
+	GkrellmPiximage	*piximage;
+	GdkPixbuf		*pixbuf;
+
+	pixbuf = gdk_pixbuf_new_from_inline(-1, data, copy_pixels, NULL);
+ 	if (!pixbuf)
+		return NULL;
+	piximage = g_new0(GkrellmPiximage, 1);
+	piximage->pixbuf = pixbuf;
+	return piximage;
+	}
