@@ -1307,6 +1307,9 @@ cb_place_button(GtkWidget *widget, gpointer data)
 				G_CALLBACK(place_plugin_window_delete_event), NULL);
 		gtk_window_set_title(GTK_WINDOW(place_plugin_window),
 				_("GKrellM Place Plugin"));
+		gtk_window_set_wmclass(GTK_WINDOW(place_plugin_window),
+				"Gkrellm_conf", "Gkrellm");
+
 		main_vbox = gtk_vbox_new(FALSE, 0);
 		gtk_container_add(GTK_CONTAINER(place_plugin_window), main_vbox);
 		place_plugin_vbox = main_vbox;
