@@ -465,7 +465,7 @@ adjust_sensors_display(gint force)
 	|  is changed.  The alert will just retrigger at next fan update.
 	*/
 	alert = gkrellm_sensor_alert(proc.sensor_fan);
-	gkrellm_reset_alert(alert);
+	gkrellm_reset_alert_soft(alert);
 
 	if (proc.sensor_temp || _GK.demo)
 		show_temperature = TRUE;
