@@ -386,6 +386,45 @@ lookup_vref(Sensor *sr, gchar *name)
 	return NULL;
 	}
 
+static void
+cb_command_process(GkrellmAlert *alert, gchar *src, gchar *buf, gint size,
+			Sensor *sensor)
+	{
+	gchar		c, *s;
+	gint		len;
+
+	if (!buf || size < 1)
+		return;
+	--size;
+	*buf = '\0';
+	if (!src)
+		return;
+	for (s = src; *s != '\0' && size > 0; ++s)
+		{
+		len = 1;
+		if (*s == '$' && *(s + 1) != '\0')
+			{
+			if ((c = *(s + 1)) == 'H')
+				len = snprintf(buf, size, "%s", gkrellm_sys_get_host_name());
+			else if (c == 's')
+				{
+				if (sensor->type == SENSOR_FAN)
+					len = snprintf(buf, size, "%.0f", sensor->value);
+				else
+					len = snprintf(buf, size, "%.2f", sensor->value);
+				}
+			else if (c == 'l')
+				len = snprintf(buf, size, "%s", sensor->name_locale);
+			++s;
+			}
+		else
+			*buf = *s;
+		size -= len;
+		buf += len;
+		}
+	*buf = '\0';
+	}
+
 GkrellmAlert *
 gkrellm_sensor_alert(gpointer sr)
 	{
@@ -404,6 +443,8 @@ gkrellm_sensor_alert_connect(gpointer sr, void (*cb_func)(), gpointer data)
 	sensor->cb_alert = cb_func;
 	sensor->cb_alert_data = data;
 	gkrellm_alert_trigger_connect(sensor->alert, cb_func, data);
+	gkrellm_alert_command_process_connect(sensor->alert,
+				cb_command_process, sensor);
 	}
 
 static gboolean
@@ -786,6 +827,8 @@ make_volt_decals(GkrellmPanel *p, GkrellmStyle *style)
 		sensor->cb_alert = cb_alert_trigger;
 		sensor->cb_alert_data = volt;
 		gkrellm_alert_trigger_connect(sensor->alert, cb_alert_trigger, volt);
+		gkrellm_alert_command_process_connect(sensor->alert,
+					cb_command_process, sensor);
 		}
 	pixel_grub = minus_width ? 1 : 0;
 	volt_bezel_width = b->left + w_volt + b->right - pixel_grub;
@@ -1071,6 +1114,8 @@ make_temperature_panel(GtkWidget *vbox, gint first_create)
 		sensor->cb_alert = cb_alert_trigger;
 		sensor->cb_alert_data = smon;
 		gkrellm_alert_trigger_connect(sensor->alert, cb_alert_trigger, smon);
+		gkrellm_alert_command_process_connect(sensor->alert,
+					cb_command_process, sensor);
 		}
 	g_free(ts_name);
 	g_free(ts_sensor);
@@ -1127,6 +1172,8 @@ make_fan_panel(GtkWidget *vbox, gint first_create)
 		sensor->cb_alert = cb_alert_trigger;
 		sensor->cb_alert_data = smon;
 		gkrellm_alert_trigger_connect(sensor->alert, cb_alert_trigger, smon);
+		gkrellm_alert_command_process_connect(sensor->alert,
+					cb_command_process, sensor);
 		}
 	g_free(ts_name);
 	g_free(ts_sensor);
@@ -1347,6 +1394,7 @@ create_sensor_alert(Sensor *s)
 		return;
 	gkrellm_alert_delay_config(s->alert, 5, 60, 0);
 	gkrellm_alert_trigger_connect(s->alert, s->cb_alert, s->cb_alert_data);
+	gkrellm_alert_command_process_connect(s->alert, cb_command_process, s);
 	gkrellm_alert_config_connect(s->alert, cb_alert_config, s);
 	}
 
