@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2002 Bill Wilson
+|  Copyright (C) 1999-2003 Bill Wilson
 |
 |  Author:  Bill Wilson    bill@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -65,7 +65,7 @@ gkrellm_sys_get_host_name(void)
 	static gboolean	have_it;
 	static gchar	buf[128];
 
-	if (!have_it && gethostname(buf, sizeof(buf)))
+	if (!have_it && gethostname(buf, sizeof(buf)) != 0)
 		strcpy(buf, "unknown");
 	have_it = TRUE;
 	return buf;
@@ -77,7 +77,7 @@ gkrellm_sys_get_system_name(void)
 	static gchar	*sname;
 	struct utsname	utsn;
 
-	if (!sname && !uname(&utsn))
+	if (!sname && uname(&utsn) > -1)
 		sname = g_strdup_printf("%s %s", utsn.sysname, utsn.release);
 	return sname;
 	}
