@@ -24,7 +24,8 @@
 
 #if !(defined(__FreeBSD__) && __FreeBSD_version < 410000) && \
     !(defined(__NetBSD__) && __NetBSD_version < 105000000) && \
-    !(defined(__OpenBSD__) && OpenBSD < 200006)
+    !(defined(__OpenBSD__) && OpenBSD < 200006) && \
+    !defined(__APPLE__)
 #define HAVE_GETIFADDRS	1
 #endif
 
