@@ -372,6 +372,13 @@ gkrellm_sys_disk_init(void)
 
 #else
 
+#if __FreeBSD_version >= 500107
+#define getdevs(stats)	devstat_getdevs(NULL, stats)
+#define selectdevs	devstat_selectdevs
+#define bytes_read	bytes[DEVSTAT_READ]
+#define bytes_written	bytes[DEVSTAT_WRITE]
+#endif
+
 gint
 gkrellm_sys_disk_order_from_name(gchar *name)
 	{
