@@ -80,10 +80,10 @@ static void
 linux_read_proc_stat(void)
 	{
 	FILE		*f;
-	gint		i, ncpu;
+	gint		n, i, ncpu;
 	gchar		*item, *arg;
 	gchar		buf[1024];
-	gulong		rblk[4], wblk[4], user, nice, sys, idle;
+	gulong		rblk[4], wblk[4], user, nice, sys, idle, iowait;
 	static gint	data_read_tick	= -1;
 
 	if (   data_read_tick == gkrellm_get_timer_ticks()	/* One read per tick */
@@ -100,9 +100,15 @@ linux_read_proc_stat(void)
 		arg = strtok(NULL, "\n");
 		if (item == NULL || arg == NULL)
 			continue;
+
 		if (item[0] == 'c' && item[1] == 'p')
 			{
-			sscanf(arg,"%lu %lu %lu %lu", &user, &nice, &sys, &idle);
+			n = sscanf(arg, "%lu %lu %lu %lu %lu",
+						&user, &nice, &sys, &idle, &iowait);
+
+			if (n == 5)			/* iowait is new in kernel 2.5	*/
+				idle += iowait;
+
 			if (n_cpus > 1)
 				{
 				if (ncpu == 0)
@@ -134,9 +140,9 @@ linux_read_proc_stat(void)
 		else if (strcmp("swap", item) == 0)
 			sscanf(arg, "%lu %lu", &swapin, &swapout);
 
-		else if (strcmp("disk_io:", item) == 0)	/* Kernel 2.4 format */
+		else if (strcmp("disk_io:", item) == 0)	/* Kernel 2.4 only format */
 			{
-			gint	major, i_disk, n;
+			gint	major, i_disk;
 			gulong	rblk, wblk, rb1, rb2, wb1, wb2;
 
 			item = strtok(arg, " \t\n");
@@ -699,6 +705,7 @@ gkrellm_sys_net_check_routes(void)
 	gchar		*s;
 	gchar		buf[512];
 
+
 	for (list = net_routed_list; list; list = list->next)
 		((NetUp *) list->data)->cur_up = FALSE;
 
@@ -1220,14 +1227,11 @@ gkrellm_sys_fs_init(void)
 	}
 
 /* ===================================================================== */
-/* Battery monitor interface */
+/* Battery monitor interface	*/
 
-#define	L_NO_BATTERY	0x80
-#define	L_ON_LINE		1
-#define	L_CHARGING		3
-#define L_UNKNOWN		0xFF
+/* ---------------------------- */
+/* ACPI battery interface		*/
 
-#define	PROC_APM_FILE				"/proc/apm"
 #define	ACPI_BATTERY_DIR			"/proc/acpi/battery/"
 #define	ACPI_AC_ADAPTOR_DIR			"/proc/acpi/ac_adapter/"
 
@@ -1465,45 +1469,138 @@ acpi_battery_data(BatteryFile *bf)
 	return TRUE;
 	}
 
-static gboolean
-apm_battery_data(void)
+/* ---------------------------- */
+/* APM battery interface		*/
+
+#define	PROC_APM_FILE				"/proc/apm"
+
+/* From: arch/i386/kernel/apm.c
+|
+| 0) Linux driver version (this will change if format changes)
+| 1) APM BIOS Version.  Usually 1.0, 1.1 or 1.2.
+| 2) APM flags from APM Installation Check (0x00):
+|	bit 0: APM_16_BIT_SUPPORT
+|	bit 1: APM_32_BIT_SUPPORT
+|	bit 2: APM_IDLE_SLOWS_CLOCK
+|	bit 3: APM_BIOS_DISABLED
+|	bit 4: APM_BIOS_DISENGAGED
+| 3) AC line status
+|	0x00: Off-line
+|	0x01: On-line
+|	0x02: On backup power (BIOS >= 1.1 only)
+|	0xff: Unknown
+| 4) Battery status
+|	0x00: High
+|	0x01: Low
+|	0x02: Critical
+|	0x03: Charging
+|	0x04: Selected battery not present (BIOS >= 1.2 only)
+|	0xff: Unknown
+| 5) Battery flag
+|	bit 0: High
+|	bit 1: Low
+|	bit 2: Critical
+|	bit 3: Charging
+|	bit 7: No system battery
+|	0xff: Unknown
+| 6) Remaining battery life (percentage of charge):
+|	0-100: valid
+|	-1: Unknown
+| 7) Remaining battery life (time units):
+|	Number of remaining minutes or seconds
+|	-1: Unknown
+| 8) min = minutes; sec = seconds
+*/
+
+#define APM_BIOS_VERSION(major, minor)	\
+			(   bios_major > (major)	\
+			 || (bios_major == (major) && bios_minor >= (minor))	\
+			)
+
+  /* AC line status values */
+#define	APM_ON_LINE		1
+
+  /* Battery status values */
+#define	APM_CHARGING	3
+#define	APM_NOT_PRESENT	4
+
+  /* Battery flag bits	*/
+#define	APM_NO_BATTERY	0x80
+
+#define APM_UNKNOWN		0xFF
+
+
+static void
+apm_battery_assign(gint id, gint bios_major, gint bios_minor,
+			gint ac_line_status, gint battery_status, gint battery_flag,
+			gint percent, gint time_left, gchar *units)
 	{
-	FILE		*f;
-	gchar		buf[128];
 	gboolean	available, on_line, charging;
-	gint		percent = 0, time_left = 0;
-	gint		ac_line_status, battery_status, flag;
-	gchar		units[32];
 
-	if ((f = fopen(PROC_APM_FILE, "r")) == NULL)
-		return FALSE;
-	fgets(buf, sizeof(buf), f);
-	fclose(f);
-
-	sscanf(buf, "%*s %*d.%*d %*x %x %x %x %d%% %d %s\n", &ac_line_status,
-			&battery_status, &flag, &percent, &time_left, units);
-	if (   (flag != L_UNKNOWN && (flag & L_NO_BATTERY))
-		|| (battery_status == L_UNKNOWN && ac_line_status == L_UNKNOWN)
+	if (   (battery_flag != APM_UNKNOWN && (battery_flag & APM_NO_BATTERY))
+		|| (battery_status == APM_UNKNOWN && ac_line_status == APM_UNKNOWN)
+		|| (battery_status == APM_NOT_PRESENT && APM_BIOS_VERSION(1,2))
 	   )
 		available = FALSE;
 	else
 		available = TRUE;
 
-	if (ac_line_status != L_UNKNOWN)
-		on_line = (ac_line_status == L_ON_LINE) ? TRUE : FALSE;
+	if (ac_line_status != APM_UNKNOWN)
+		on_line = (ac_line_status == APM_ON_LINE) ? TRUE : FALSE;
 	else
-		on_line = (battery_status == L_CHARGING) ? FALSE : TRUE;
+		on_line = (battery_status == APM_CHARGING) ? FALSE : TRUE;
 
-	if (battery_status != L_UNKNOWN)
-		charging= (battery_status == L_CHARGING) ? TRUE : FALSE;
+	if (battery_status != APM_UNKNOWN)
+		charging= (battery_status == APM_CHARGING) ? TRUE : FALSE;
 	else
-		charging = (ac_line_status == L_ON_LINE) ? TRUE : FALSE;
+		charging = (ac_line_status == APM_ON_LINE) ? TRUE : FALSE;
 
 	if (!strcmp(units, "sec") && time_left > 0)
 		time_left /= 60;
 
-	gkrellm_battery_assign_data(0, available, on_line, charging,
+	gkrellm_battery_assign_data(id, available, on_line, charging,
 				percent, time_left);
+	}
+
+static gboolean
+apm_battery_data(void)
+	{
+	FILE		*f;
+	gchar		buf[128], units[32];
+	gint		percent = 0, time_left = 0;
+	gint		ac_line_status, battery_status, battery_flag;
+	gint		bios_major, bios_minor;
+	gint		id, n_batteries;
+
+	if ((f = fopen(PROC_APM_FILE, "r")) == NULL)
+		return FALSE;
+	fgets(buf, sizeof(buf), f);
+
+	sscanf(buf, "%*s %d.%d %*x %x %x %x %d%% %d %32s\n",
+				&bios_major, &bios_minor,
+				&ac_line_status, &battery_status, &battery_flag,
+				&percent, &time_left, units);
+
+	if (   fgets(buf, sizeof(buf), f)
+		&& sscanf(buf, "%d\n", &n_batteries) == 1
+	   )
+		{
+		/* Handle dual APM battery patch.
+		*/
+		while (n_batteries-- > 0 && fgets(buf, sizeof(buf), f))
+			{
+			sscanf(buf, "%d %x %x %d%% %d %32s\n", &id,
+					&battery_status, &battery_flag,
+					&percent, &time_left, units);
+			apm_battery_assign(id - 1, bios_major, bios_minor, ac_line_status,
+					battery_status, battery_flag, percent, time_left, units);
+			}
+		}
+	else
+		apm_battery_assign(0, bios_major, bios_minor, ac_line_status,
+				battery_status, battery_flag, percent, time_left, units);
+
+	fclose(f);
 	return TRUE;
 	}
 
