@@ -84,7 +84,7 @@ typedef struct {
 					    GdkPixmap *, gchar *);
     GkrellmChartdata *(*gkrellm_add_default_chartdata)(GkrellmChart *, gchar *);
     void		(*gkrellm_alloc_chartdata)(GkrellmChart *);
-//    void		(*gkrellm_store_chartdata)(GkrellmChart *, gulong, ...);
+    void		(*gkrellm_store_chartdata)(GkrellmChart *, gulong, gulong, gulong);
     void		(*gkrellm_draw_chartdata)(GkrellmChart *);
     void		(*gkrellm_monotonic_chartdata)(GkrellmChartdata *, gboolean);
     gboolean	(*gkrellm_get_chartdata_hide)(GkrellmChartdata *);
@@ -455,7 +455,6 @@ typedef struct {
 
       /* Functions new for 2.1.8
       */
-#if 0
 	void		(*gkrellm_panel_label_on_top_of_decals)(GkrellmPanel *p,
 						gboolean mode);
 	gboolean	(*gkrellm_alert_is_activated)(GkrellmAlert *alert);
@@ -471,9 +470,19 @@ typedef struct {
 	void		(*gkrellm_gtk_alert_button)(GtkWidget *box, GtkWidget **button,
 						gboolean expand, gboolean fill, gint pad,
 						gboolean pack_start, void (*cb_func)(), gpointer data);
-#endif
- 
 
+      /* Functions new for 2.1.9
+      */
+#if 0
+	GkrellmPiximage *(*gkrellm_piximage_new_from_inline)(const guint8 *data,
+						gboolean copy_pixels);
+    gboolean    (*gkrellm_load_piximage_from_inline)(gchar *name,
+						const guint8 *data, GkrellmPiximage **image,
+						gchar *subdir, gboolean copy_pixels);
+	void		(*gkrellm_alert_commands_config)(GkrellmAlert *alert,
+                        gboolean alarm, gboolean warn);
+    void		(*gkrellm_reset_alert_soft)(GkrellmAlert *);
+#endif
 } win32_plugin_callbacks;
 
 extern win32_plugin_callbacks* callbacks;
